import { AttributedTokenIdentity, AwsSdkTokenFeatures } from "@aws-sdk/types";
export declare function setTokenFeature<F extends keyof AwsSdkTokenFeatures>(
  token: AttributedTokenIdentity,
  feature: F,
  value: AwsSdkTokenFeatures[F]
): AttributedTokenIdentity;
