/**
 * ./src/classes/tailor.ts
 * penguins-eggs v.25.7.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
import { IMateria } from '../interfaces/index.js';
/**
 *
 */
export default class Tailor {
    materials: IMateria;
    private category;
    private costume;
    private echo;
    private log;
    private toNull;
    private verbose;
    private wardrobe;
    /**
     * @param wardrobe
     * @param costume
     */
    constructor(costume: string, category?: string);
    /**
     *
     * @param packages
     * @param verbose
     * @param section
     * @returns
     */
    packagesExists(wanted: string[]): Promise<string[]>;
    /**
     * - check if every package if installed
     * - if find any packages to install, install it
     */
    packagesInstall(packages: string[], comment?: string, cmd?: string): Promise<void>;
    /**
     *
     */
    prepare(verbose?: boolean, no_accessories?: boolean, no_firmwares?: boolean): Promise<void>;
    /**
     *
     * @param cmd
     * @param echo
     * @returns
     */
    tryCheckSuccess(cmd: string, echo: {}): Promise<boolean>;
}
