/**
 * ./src/interfaces/index.ts
 * penguins-eggs v.25.7.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
export { IBranding } from './calamares/i-calamares-branding.js';
export { IAddons } from './i-addons.js';
export { IApp } from './i-app.js';
export { IDevice, IDevices } from './i-devices.js';
export { IDistro } from './i-distro.js';
export { IEggsConfig } from './i-eggs-config.js';
export { IExcludes } from './i-excludes.js';
export { IExec } from './i-exec.js';
export { IInitrd } from './i-initrd.js';
export { IInstall } from './i-install.js';
export { IInstaller } from './i-installer.js';
export { ILuksPassphrase } from './i-luks-passphrase.js';
export { IMateria, IRepos } from './i-materia.js';
export { INet } from './i-net.js';
export { IPartitions } from './i-partitions.js';
export { IRemix } from './i-remix.js';
export { ISettings } from './i-settings.js';
export { IUser } from './i-user.js';
export { IWorkDir } from './i-workdir.js';
