/**
 * ./src/interfaces/i-analyze.ts
 * penguins-eggs v.25.7.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
export default class IAnalyze {
    gecos = '';
    gid = '';
    home = '';
    login = '';
    password = '';
    shell = '';
    size = 0;
    uid = '';
}
