/**
 * Check if the given value is *phrasing* content.
 *
 * @param {Nodes} value
 *   Node to check.
 * @returns {boolean}
 *   Whether `value` is phrasing content.
 */
export function phrasing(value: Nodes): boolean;
export type Nodes = import('hast').Nodes;
