/**
 * ./src/components/users.tsx
 * penguins-eggs v.25.7.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
import React from 'react';
type UsersProps = {
    autologin?: boolean;
    fullname?: string;
    hostname?: string;
    password?: string;
    rootPassword?: string;
    sameUserPassword?: boolean;
    username?: string;
};
/**
 *
 * @param param0
 * @returns
 */
export default function Users({ autologin, fullname, hostname, password, rootPassword, sameUserPassword, username }: UsersProps): React.JSX.Element;
export {};
