module.exports={A:{A:{"2":"K D E F A B 3C"},B:{"1":"0 1 2 3 4 5 6 7 8 9 Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I","2":"C L M G N O P","1028":"W X","1540":"Q H R S T U V"},C:{"1":"0 1 2 3 4 5 6 7 8 9 CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC cC 5C 6C","2":"4C","164":"WC J cB K D E F A B C L M G N O P dB BB CB DB EB FB GB HB IB JB KB eB fB gB hB iB jB kB lB mB nB oB 7C 8C","1540":"pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B XC 7B YC 8B 9B AC BC"},D:{"1":"0 1 2 3 4 5 6 7 8 9 Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC cC","292":"J cB K D E F A B C L M G N O P dB BB CB DB EB FB GB HB IB JB KB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B XC 7B YC 8B 9B AC BC CC DC EC","1028":"W X","1540":"FC GC HC IC JC KC LC MC NC OC Q H R S T U V"},E:{"1":"G GD fC gC SC HD TC hC iC jC kC lC ID UC mC nC oC pC qC JD VC rC sC tC uC vC wC xC yC zC 0C KD","292":"J cB K D E F A B C 9C dC AD BD CD DD eC QC","1540":"L M RC ED","3076":"FD"},F:{"1":"0 1 2 3 4 5 6 7 8 9 MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB","2":"F B C LD MD ND OD QC 1C PD RC","292":"G N O P dB BB CB DB EB FB GB HB IB JB KB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B","1028":"KC LC","1540":"4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC"},G:{"1":"jD fC gC SC kD TC hC iC jC kC lC lD UC mC nC oC pC qC mD VC rC sC tC uC vC wC xC yC zC 0C","292":"E dC QD 2C RD SD TD UD VD WD XD YD ZD aD bD","1540":"cD dD eD fD gD hD","3076":"iD"},H:{"2":"nD"},I:{"1":"I","292":"WC J oD pD qD rD 2C sD tD"},J:{"292":"D A"},K:{"1":"H","2":"A B C QC 1C RC"},L:{"1":"I"},M:{"1":"PC"},N:{"2":"A B"},O:{"1":"SC"},P:{"1":"BB CB DB EB FB GB HB IB JB KB 3D TC UC VC 4D","292":"J uD vD wD xD yD","1540":"eC zD 0D 1D 2D"},Q:{"1540":"5D"},R:{"1":"6D"},S:{"1":"8D","1540":"7D"}},B:5,C:"CSS Logical Properties",D:true};
