import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import {
  CloudFrontClientResolvedConfig,
  ServiceInputTypes,
  ServiceOutputTypes,
} from "../CloudFrontClient";
import {
  GetFieldLevelEncryptionProfileRequest,
  GetFieldLevelEncryptionProfileResult,
} from "../models/models_0";
export { __MetadataBearer };
export { $Command };
export interface GetFieldLevelEncryptionProfileCommandInput
  extends GetFieldLevelEncryptionProfileRequest {}
export interface GetFieldLevelEncryptionProfileCommandOutput
  extends GetFieldLevelEncryptionProfileResult,
    __MetadataBearer {}
declare const GetFieldLevelEncryptionProfileCommand_base: {
  new (
    input: GetFieldLevelEncryptionProfileCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    GetFieldLevelEncryptionProfileCommandInput,
    GetFieldLevelEncryptionProfileCommandOutput,
    CloudFrontClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  new (
    input: GetFieldLevelEncryptionProfileCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    GetFieldLevelEncryptionProfileCommandInput,
    GetFieldLevelEncryptionProfileCommandOutput,
    CloudFrontClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
export declare class GetFieldLevelEncryptionProfileCommand extends GetFieldLevelEncryptionProfileCommand_base {
  protected static __types: {
    api: {
      input: GetFieldLevelEncryptionProfileRequest;
      output: GetFieldLevelEncryptionProfileResult;
    };
    sdk: {
      input: GetFieldLevelEncryptionProfileCommandInput;
      output: GetFieldLevelEncryptionProfileCommandOutput;
    };
  };
}
