import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import {
  CloudFrontClientResolvedConfig,
  ServiceInputTypes,
  ServiceOutputTypes,
} from "../CloudFrontClient";
import {
  GetOriginRequestPolicyRequest,
  GetOriginRequestPolicyResult,
} from "../models/models_1";
export { __MetadataBearer };
export { $Command };
export interface GetOriginRequestPolicyCommandInput
  extends GetOriginRequestPolicyRequest {}
export interface GetOriginRequestPolicyCommandOutput
  extends GetOriginRequestPolicyResult,
    __MetadataBearer {}
declare const GetOriginRequestPolicyCommand_base: {
  new (
    input: GetOriginRequestPolicyCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    GetOriginRequestPolicyCommandInput,
    GetOriginRequestPolicyCommandOutput,
    CloudFrontClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  new (
    input: GetOriginRequestPolicyCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    GetOriginRequestPolicyCommandInput,
    GetOriginRequestPolicyCommandOutput,
    CloudFrontClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
export declare class GetOriginRequestPolicyCommand extends GetOriginRequestPolicyCommand_base {
  protected static __types: {
    api: {
      input: GetOriginRequestPolicyRequest;
      output: GetOriginRequestPolicyResult;
    };
    sdk: {
      input: GetOriginRequestPolicyCommandInput;
      output: GetOriginRequestPolicyCommandOutput;
    };
  };
}
