export declare function supportsWebCrypto(window: Window): boolean;
export declare function supportsSecureRandom(window: Window): boolean;
export declare function supportsSubtleCrypto(subtle: SubtleCrypto): boolean;
export declare function supportsZeroByteGCM(subtle: SubtleCrypto): Promise<boolean>;
