export declare function crc32c(data: Uint8Array): number;
export declare class Crc32c {
    private checksum;
    update(data: Uint8Array): this;
    digest(): number;
}
export { AwsCrc32c } from "./aws_crc32c";
