import type { AwsIdentityProperties } from "@aws-sdk/types";
import type { AwsCredentialIdentity, ParsedIniData } from "@smithy/types";
import type { FromIniInit } from "./fromIni";
/**
 * @internal
 */
export declare const isLoginProfile: (data: ParsedIniData[string]) => boolean;
/**
 * @internal
 */
export declare const resolveLoginCredentials: (profileName: string, options: FromIniInit, callerClientConfig?: AwsIdentityProperties["callerClientConfig"]) => Promise<AwsCredentialIdentity>;
