import {
  GetRoleCredentialsCommand,
  SSOClient,
} from "@aws-sdk/nested-clients/sso";
export { GetRoleCredentialsCommand, SSOClient };
export {
  SSOClientConfig,
  GetRoleCredentialsCommandOutput,
} from "@aws-sdk/nested-clients/sso";
