/**
 * ./src/lib/kill_me_softly.ts
 * penguins-eggs v.25.7.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
/**
 *
 */
export default function killMeSoftly(eggsRoot?: string, eggsMnt?: string, isos?: boolean): Promise<void>;
