import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import {
  CloudFrontClientResolvedConfig,
  ServiceInputTypes,
  ServiceOutputTypes,
} from "../CloudFrontClient";
import {
  CreateFieldLevelEncryptionProfileRequest,
  CreateFieldLevelEncryptionProfileResult,
} from "../models/models_0";
export { __MetadataBearer };
export { $Command };
export interface CreateFieldLevelEncryptionProfileCommandInput
  extends CreateFieldLevelEncryptionProfileRequest {}
export interface CreateFieldLevelEncryptionProfileCommandOutput
  extends CreateFieldLevelEncryptionProfileResult,
    __MetadataBearer {}
declare const CreateFieldLevelEncryptionProfileCommand_base: {
  new (
    input: CreateFieldLevelEncryptionProfileCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    CreateFieldLevelEncryptionProfileCommandInput,
    CreateFieldLevelEncryptionProfileCommandOutput,
    CloudFrontClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  new (
    input: CreateFieldLevelEncryptionProfileCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    CreateFieldLevelEncryptionProfileCommandInput,
    CreateFieldLevelEncryptionProfileCommandOutput,
    CloudFrontClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
export declare class CreateFieldLevelEncryptionProfileCommand extends CreateFieldLevelEncryptionProfileCommand_base {
  protected static __types: {
    api: {
      input: CreateFieldLevelEncryptionProfileRequest;
      output: CreateFieldLevelEncryptionProfileResult;
    };
    sdk: {
      input: CreateFieldLevelEncryptionProfileCommandInput;
      output: CreateFieldLevelEncryptionProfileCommandOutput;
    };
  };
}
