/**
 * ./src/classes/ovary.d/luks-root.ts
 * penguins-eggs v.25.10.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
import Ovary from '../ovary.js';
/**
 * luksRoot()
 * create a container LUKS with the entire
 * filesystem.squashfs
 */
export declare function luksRoot(this: Ovary): Promise<void>;
