/**
 * ./src/krill/modules/hostnames.ts
 * penguins-eggs v.25.7.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 * https://stackoverflow.com/questions/23876782/how-do-i-split-a-typescript-class-into-multiple-files
 */
import Sequence from '../../classes/sequence.js';
/**
 * hostname
 */
export default function hostname(this: Sequence, domain?: string): Promise<void>;
