/**
 * src/krill/classes/krill-enums.ts
 * penguins-eggs v.25.7.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
/**
 *
 */
export var InstallationMode;
(function (InstallationMode) {
    InstallationMode["EraseDisk"] = "Erase disk";
    InstallationMode["Luks"] = "Erase disk/Encrypted";
    InstallationMode["Replace"] = "Replace partition";
})(InstallationMode || (InstallationMode = {}));
/**
 *
 */
export var SwapChoice;
(function (SwapChoice) {
    SwapChoice["File"] = "file";
    SwapChoice["None"] = "none";
    SwapChoice["Small"] = "small";
    SwapChoice["Suspend"] = "suspend";
})(SwapChoice || (SwapChoice = {}));
export var Bios;
(function (Bios) {
    Bios["EFI"] = "efi";
    Bios["Legacy"] = "legacy";
})(Bios || (Bios = {}));
export var FsType;
(function (FsType) {
    FsType["btrfs"] = "btrfs";
    FsType["ext2"] = "ext2";
    FsType["ext3"] = "ext3";
    FsType["ext4"] = "ext4";
    FsType["ntfs"] = "ntfs";
    FsType["xfs"] = "xfs";
    FsType["zfs"] = "zfs";
})(FsType || (FsType = {}));
