/**
 * ./src/classes/yolk.ts
 * penguins-eggs v.25.7.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
/**
 *
 */
export default class Yolk {
    echo: {};
    verbose: boolean;
    yolkDir: string;
    /**
     *
     */
    create(verbose?: boolean): Promise<void>;
    /**
     * Svuota la repo yolk
     */
    erase(): Promise<void>;
    /**
     * Check if yoil exists and it's a repo
     */
    exists(): boolean;
    /**
     * if depends are not Installed
     * download depends
     * @param depends
     */
    installDeps(depends: string[]): Promise<void>;
}
