/**
 * ./src/interfaces/i-config-tools.ts
 * penguins-eggs v.25.7.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
export interface IEggsConfigTools {
    filterPackages: string;
    localPathIso: string;
    remoteHost: string;
    remotePathIso: string;
    remotePathPackages: string;
    remoteUser: string;
}
