/**
 * ./src/components/partitions.tsx
 * penguins-eggs v.25.7.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
import React from 'react';
import { SwapChoice } from '../classes/krill_enums.js';
type partitionsProps = {
    filesystemType?: string;
    installationDevice?: string;
    installationMode?: string;
    replacedPartition?: string;
    userSwapChoice?: SwapChoice;
};
export default function Partitions({ filesystemType, installationDevice, installationMode, replacedPartition, userSwapChoice }: partitionsProps): React.JSX.Element;
export {};
