/**
 * ./src/classes/ovary.d/luks-helpers.ts
 * penguins-eggs v.25.10.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
import Ovary from '../ovary.js';
import { type CryptoConfig } from './luks-interactive-crypto-config.js';
/**
 * Funzione helper per eseguire comandi esterni in modo asincrono,
 * gestendo lo standard input per passare le password.
 * Restituisce una Promise che si risolve al successo o si rigetta in caso di errore.
 */
export declare function luksExecuteCommand(this: Ovary, command: string, args: string[], stdinData?: string): Promise<void>;
/**
 * buildLuksFormatArgs
 */
export declare function buildLuksFormatArgs(this: Ovary, config: CryptoConfig, luksFile: string): string[];
