export interface GetCredentialsForIdentityInput {
  IdentityId: string | undefined;
  Logins?: Record<string, string> | undefined;
  CustomRoleArn?: string | undefined;
}
export interface Credentials {
  AccessKeyId?: string | undefined;
  SecretKey?: string | undefined;
  SessionToken?: string | undefined;
  Expiration?: Date | undefined;
}
export interface GetCredentialsForIdentityResponse {
  IdentityId?: string | undefined;
  Credentials?: Credentials | undefined;
}
export interface GetIdInput {
  AccountId?: string | undefined;
  IdentityPoolId: string | undefined;
  Logins?: Record<string, string> | undefined;
}
export interface GetIdResponse {
  IdentityId?: string | undefined;
}
