/**
 * ./src/classes/incubation/installer.ts
 * penguins-eggs v.25.7.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
import { IInstaller } from '../../interfaces/index.js';
/**
 *
 * @returns
 */
export declare function installer(): IInstaller;
