/**
 * src/classes/ovary.d/users-remove.ts
 * penguins-eggs v.25.7.x / ecmascript 2020
 * REFACTORED: Uses "The SysUser Master" class.
 * Cleans up host users from the ISO filesystem safely.
 */
import Ovary from '../ovary.js';
export default function usersRemove(this: Ovary): Promise<void>;
