module.exports={A:{A:{"1":"B","4":"K D E F A 3C"},B:{"1":"C L M G N","129":"0 1 2 3 4 5 6 7 8 9 O P Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I"},C:{"1":"K D E F A B C L M G N O P dB BB CB DB EB FB GB HB IB JB KB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB","4":"4C WC J cB 7C 8C","129":"0 1 2 3 4 5 6 7 8 9 zB 0B 1B 2B 3B 4B 5B 6B XC 7B YC 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC cC 5C 6C"},D:{"1":"tB uB vB wB xB yB zB 0B 1B 2B","4":"J cB K","129":"0 1 2 3 4 5 6 7 8 9 D E F A B C L M G N O P dB BB CB DB EB FB GB HB IB JB KB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB 3B 4B 5B 6B XC 7B YC 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC cC"},E:{"4":"J cB 9C dC","129":"K D E F A B C L M G AD BD CD DD eC QC RC ED FD GD fC gC SC HD TC hC iC jC kC lC ID UC mC nC oC pC qC JD VC rC sC tC uC vC wC xC yC zC 0C KD"},F:{"1":"C gB hB iB jB kB lB mB nB oB pB QC 1C PD RC","4":"F B LD MD ND OD","129":"0 1 2 3 4 5 6 7 8 9 G N O P dB BB CB DB EB FB GB HB IB JB KB eB fB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB"},G:{"4":"dC QD 2C","129":"E RD SD TD UD VD WD XD YD ZD aD bD cD dD eD fD gD hD iD jD fC gC SC kD TC hC iC jC kC lC lD UC mC nC oC pC qC mD VC rC sC tC uC vC wC xC yC zC 0C"},H:{"4":"nD"},I:{"4":"oD pD qD","129":"WC J I rD 2C sD tD"},J:{"129":"D A"},K:{"1":"C QC 1C RC","4":"A B","129":"H"},L:{"129":"I"},M:{"129":"PC"},N:{"1":"B","4":"A"},O:{"129":"SC"},P:{"129":"J BB CB DB EB FB GB HB IB JB KB uD vD wD xD yD eC zD 0D 1D 2D 3D TC UC VC 4D"},Q:{"129":"5D"},R:{"129":"6D"},S:{"1":"7D","129":"8D"}},B:1,C:"dataset & data-* attributes",D:true};
