import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import {
  CloudFrontClientResolvedConfig,
  ServiceInputTypes,
  ServiceOutputTypes,
} from "../CloudFrontClient";
import {
  UpdateDistributionRequest,
  UpdateDistributionResult,
} from "../models/models_1";
export { __MetadataBearer };
export { $Command };
export interface UpdateDistributionCommandInput
  extends UpdateDistributionRequest {}
export interface UpdateDistributionCommandOutput
  extends UpdateDistributionResult,
    __MetadataBearer {}
declare const UpdateDistributionCommand_base: {
  new (
    input: UpdateDistributionCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    UpdateDistributionCommandInput,
    UpdateDistributionCommandOutput,
    CloudFrontClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  new (
    input: UpdateDistributionCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    UpdateDistributionCommandInput,
    UpdateDistributionCommandOutput,
    CloudFrontClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
export declare class UpdateDistributionCommand extends UpdateDistributionCommand_base {
  protected static __types: {
    api: {
      input: UpdateDistributionRequest;
      output: UpdateDistributionResult;
    };
    sdk: {
      input: UpdateDistributionCommandInput;
      output: UpdateDistributionCommandOutput;
    };
  };
}
