/**
 * ./src/classes/incubation/fisherman-helper/packages.ts
 * penguins-eggs v.25.7.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
import { IDistro } from '../../../interfaces/index.js';
/**
 *
 * @param distro
 * @returns yaml-string
 */
export declare function remove(distro: IDistro): string;
/**
 *
 * @param distro
 * @returns yaml-string
 */
export declare function tryInstall(distro: IDistro): string;
