module.exports={A:{A:{"2":"K D E 3C","2561":"A B","2692":"F"},B:{"1":"0 1 2 3 4 5 6 7 8 9 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I","2561":"C L M G N O P"},C:{"1":"0 1 2 3 4 5 6 7 8 9 xB yB zB 0B 1B 2B 3B 4B 5B 6B XC 7B YC 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC cC 5C 6C","16":"4C","1537":"J cB K D E F A B C L M G N O P dB BB CB DB EB FB GB HB IB JB KB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB 8C","1796":"WC 7C"},D:{"1":"0 1 2 3 4 5 6 7 8 9 CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC cC","16":"J cB K D E F A B C L M","1025":"jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B XC 7B YC 8B 9B AC BC","1537":"G N O P dB BB CB DB EB FB GB HB IB JB KB eB fB gB hB iB"},E:{"1":"M G ED FD GD fC gC SC HD TC hC iC jC kC lC ID UC mC nC oC pC qC JD VC rC sC tC uC vC wC xC yC zC 0C KD","16":"J cB K 9C dC","1025":"D E F A B C BD CD DD eC QC","1537":"AD","4097":"L RC"},F:{"1":"0 1 2 3 4 5 6 7 8 9 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB RC","16":"F B C LD MD ND OD QC 1C","260":"PD","1025":"DB EB FB GB HB IB JB KB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB","1537":"G N O P dB BB CB"},G:{"1":"eD fD gD hD iD jD fC gC SC kD TC hC iC jC kC lC lD UC mC nC oC pC qC mD VC rC sC tC uC vC wC xC yC zC 0C","16":"dC QD 2C","1025":"E UD VD WD XD YD ZD aD bD","1537":"RD SD TD","4097":"cD dD"},H:{"2":"nD"},I:{"16":"oD pD","1025":"I tD","1537":"WC J qD rD 2C sD"},J:{"1025":"A","1537":"D"},K:{"1":"A B C H QC 1C RC"},L:{"1":"I"},M:{"1":"PC"},N:{"2561":"A B"},O:{"1":"SC"},P:{"1025":"J BB CB DB EB FB GB HB IB JB KB uD vD wD xD yD eC zD 0D 1D 2D 3D TC UC VC 4D"},Q:{"1":"5D"},R:{"1":"6D"},S:{"1":"8D","1537":"7D"}},B:1,C:"input event",D:true};
