/**
 * ./src/classes/ovary.d/luks-shrink.ts
 * penguins-eggs v.25.10.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
import Ovary from '../ovary.js';
/**
 * luksShrink
 * Riduce in sicurezza un volume LUKS (root o home) minimizzando lo spazio
 * ma garantendo l'integrità dei dati e l'allineamento dei blocchi.
 */
export declare function luksShrink(this: Ovary): Promise<void>;
