/**
 * ./src/interfaces/i-calamares-branding.ts
 * penguins-eggs v.25.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 *
 * Questa interfaccia è allineata con la struttura reale di branding.desc
 * (basata sull'output 'cat /etc/calamares/branding/eggs/branding.desc').
 */
export {};
