import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import {
  CloudFrontClientResolvedConfig,
  ServiceInputTypes,
  ServiceOutputTypes,
} from "../CloudFrontClient";
import {
  ListContinuousDeploymentPoliciesRequest,
  ListContinuousDeploymentPoliciesResult,
} from "../models/models_1";
export { __MetadataBearer };
export { $Command };
export interface ListContinuousDeploymentPoliciesCommandInput
  extends ListContinuousDeploymentPoliciesRequest {}
export interface ListContinuousDeploymentPoliciesCommandOutput
  extends ListContinuousDeploymentPoliciesResult,
    __MetadataBearer {}
declare const ListContinuousDeploymentPoliciesCommand_base: {
  new (
    input: ListContinuousDeploymentPoliciesCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    ListContinuousDeploymentPoliciesCommandInput,
    ListContinuousDeploymentPoliciesCommandOutput,
    CloudFrontClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  new (
    ...[input]: [] | [ListContinuousDeploymentPoliciesCommandInput]
  ): import("@smithy/smithy-client").CommandImpl<
    ListContinuousDeploymentPoliciesCommandInput,
    ListContinuousDeploymentPoliciesCommandOutput,
    CloudFrontClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
export declare class ListContinuousDeploymentPoliciesCommand extends ListContinuousDeploymentPoliciesCommand_base {
  protected static __types: {
    api: {
      input: ListContinuousDeploymentPoliciesRequest;
      output: ListContinuousDeploymentPoliciesResult;
    };
    sdk: {
      input: ListContinuousDeploymentPoliciesCommandInput;
      output: ListContinuousDeploymentPoliciesCommandOutput;
    };
  };
}
