import type { UserAgentPair } from "@smithy/types";
/**
 * Returns the tyescript name and version as a user agent pair, if present.
 * @internal
 */
export declare const getTypeScriptUserAgentPair: () => Promise<UserAgentPair | undefined>;
