/**
 * ./src/commands/produce.ts
 * penguins-eggs v.25.7.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
import { Command } from '@oclif/core';
export default class Produce extends Command {
    static description: string;
    static examples: string[];
    static flags: {
        addons: import("@oclif/core/interfaces").OptionFlag<string[] | undefined, import("@oclif/core/interfaces").CustomOptions>;
        basename: import("@oclif/core/interfaces").OptionFlag<string | undefined, import("@oclif/core/interfaces").CustomOptions>;
        fdt: import("@oclif/core/interfaces").OptionFlag<string | undefined, import("@oclif/core/interfaces").CustomOptions>;
        clone: import("@oclif/core/interfaces").BooleanFlag<boolean>;
        excludes: import("@oclif/core/interfaces").OptionFlag<string[] | undefined, import("@oclif/core/interfaces").CustomOptions>;
        fullcrypt: import("@oclif/core/interfaces").BooleanFlag<boolean>;
        help: import("@oclif/core/interfaces").BooleanFlag<void>;
        hidden: import("@oclif/core/interfaces").BooleanFlag<boolean>;
        homecrypt: import("@oclif/core/interfaces").BooleanFlag<boolean>;
        includeRootHome: import("@oclif/core/interfaces").BooleanFlag<boolean>;
        kernel: import("@oclif/core/interfaces").OptionFlag<string | undefined, import("@oclif/core/interfaces").CustomOptions>;
        links: import("@oclif/core/interfaces").OptionFlag<string[] | undefined, import("@oclif/core/interfaces").CustomOptions>;
        max: import("@oclif/core/interfaces").BooleanFlag<boolean>;
        noicon: import("@oclif/core/interfaces").BooleanFlag<boolean>;
        nointeractive: import("@oclif/core/interfaces").BooleanFlag<boolean>;
        pendrive: import("@oclif/core/interfaces").BooleanFlag<boolean>;
        prefix: import("@oclif/core/interfaces").OptionFlag<string | undefined, import("@oclif/core/interfaces").CustomOptions>;
        release: import("@oclif/core/interfaces").BooleanFlag<boolean>;
        script: import("@oclif/core/interfaces").BooleanFlag<boolean>;
        standard: import("@oclif/core/interfaces").BooleanFlag<boolean>;
        theme: import("@oclif/core/interfaces").OptionFlag<string | undefined, import("@oclif/core/interfaces").CustomOptions>;
        verbose: import("@oclif/core/interfaces").BooleanFlag<boolean>;
        yolk: import("@oclif/core/interfaces").BooleanFlag<boolean>;
    };
    run(): Promise<void>;
}
