import { TypeRegistry } from "@smithy/core/schema";
import {
  StaticErrorSchema,
  StaticOperationSchema,
  StaticStructureSchema,
} from "@smithy/types";
export declare var CognitoIdentityServiceException$: StaticErrorSchema;
export declare var ExternalServiceException$: StaticErrorSchema;
export declare var InternalErrorException$: StaticErrorSchema;
export declare var InvalidIdentityPoolConfigurationException$: StaticErrorSchema;
export declare var InvalidParameterException$: StaticErrorSchema;
export declare var LimitExceededException$: StaticErrorSchema;
export declare var NotAuthorizedException$: StaticErrorSchema;
export declare var ResourceConflictException$: StaticErrorSchema;
export declare var ResourceNotFoundException$: StaticErrorSchema;
export declare var TooManyRequestsException$: StaticErrorSchema;
export declare const errorTypeRegistries: TypeRegistry[];
export declare var Credentials$: StaticStructureSchema;
export declare var GetCredentialsForIdentityInput$: StaticStructureSchema;
export declare var GetCredentialsForIdentityResponse$: StaticStructureSchema;
export declare var GetIdInput$: StaticStructureSchema;
export declare var GetIdResponse$: StaticStructureSchema;
export declare var GetCredentialsForIdentity$: StaticOperationSchema;
export declare var GetId$: StaticOperationSchema;
