module.exports={A:{A:{"1":"B","2":"K D E F 3C","164":"A"},B:{"1":"0 1 2 3 4 5 6 7 8 9 C L M G N O P Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I"},C:{"1":"0 1 2 3 4 5 6 7 8 9 XC 7B YC 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC cC 5C 6C","2":"4C WC J cB 7C 8C","8":"K D E F A B C L M G N O P dB BB CB DB EB FB GB HB IB JB KB eB fB gB hB iB jB kB lB mB nB oB","328":"pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B"},D:{"1":"0 1 2 3 4 5 6 7 8 9 3B 4B 5B 6B XC 7B YC 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC cC","2":"J cB K D E F A B C L M G N O P dB BB CB","8":"DB EB FB GB HB IB JB KB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB","584":"0B 1B 2B"},E:{"1":"L M G ED FD GD fC gC SC HD TC hC iC jC kC lC ID UC mC nC oC pC qC JD VC rC sC tC uC vC wC xC yC zC 0C KD","2":"J cB K 9C dC AD","8":"D E F A B C BD CD DD eC QC","1096":"RC"},F:{"1":"0 1 2 3 4 5 6 7 8 9 qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB","2":"F B C LD MD ND OD QC 1C PD RC","8":"G N O P dB BB CB DB EB FB GB HB IB JB KB eB fB gB hB iB jB kB lB mB","584":"nB oB pB"},G:{"1":"eD fD gD hD iD jD fC gC SC kD TC hC iC jC kC lC lD UC mC nC oC pC qC mD VC rC sC tC uC vC wC xC yC zC 0C","8":"E dC QD 2C RD SD TD UD VD WD XD YD ZD aD bD cD","6148":"dD"},H:{"2":"nD"},I:{"1":"I","8":"WC J oD pD qD rD 2C sD tD"},J:{"8":"D A"},K:{"1":"H","2":"A","8":"B C QC 1C RC"},L:{"1":"I"},M:{"1":"PC"},N:{"1":"B","36":"A"},O:{"1":"SC"},P:{"1":"BB CB DB EB FB GB HB IB JB KB vD wD xD yD eC zD 0D 1D 2D 3D TC UC VC 4D","2":"uD","8":"J"},Q:{"1":"5D"},R:{"1":"6D"},S:{"1":"8D","328":"7D"}},B:2,C:"Pointer events",D:true};
