import type { Provider } from "@smithy/types";
/**
 * @internal
 */
export interface AwsRegionExtensionConfiguration {
    setRegion(region: Provider<string>): void;
    region(): Provider<string>;
}
