/**
 * ./src/classes/ovary.d/merge.ts
 * penguins-eggs v.25.7.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
import Ovary from '../ovary.js';
/**
 * Ritorna true se c'è bisogno del mount --bind
 *
 * Ci sono quattro tipologie:
 *
 * - copied
 * - mergedAndOverlay
 * - merged
 * - just create
 */
export declare function copied(this: Ovary, dir: string): boolean;
/**
 *
 */
export declare function mergedAndOverlay(this: Ovary, dir: string): boolean;
/**
 * merged
 */
export declare function merged(this: Ovary, dir: string): boolean;
