'use strict';

var types = require('@smithy/types');

exports.HostAddressType = void 0;
(function (HostAddressType) {
    HostAddressType["AAAA"] = "AAAA";
    HostAddressType["A"] = "A";
})(exports.HostAddressType || (exports.HostAddressType = {}));

exports.EndpointURLScheme = types.EndpointURLScheme;
exports.HttpAuthLocation = types.HttpAuthLocation;
exports.RequestHandlerProtocol = types.RequestHandlerProtocol;
