import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import {
  CloudFrontClientResolvedConfig,
  ServiceInputTypes,
  ServiceOutputTypes,
} from "../CloudFrontClient";
import { DeletePublicKeyRequest } from "../models/models_0";
export { __MetadataBearer };
export { $Command };
export interface DeletePublicKeyCommandInput extends DeletePublicKeyRequest {}
export interface DeletePublicKeyCommandOutput extends __MetadataBearer {}
declare const DeletePublicKeyCommand_base: {
  new (
    input: DeletePublicKeyCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    DeletePublicKeyCommandInput,
    DeletePublicKeyCommandOutput,
    CloudFrontClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  new (
    input: DeletePublicKeyCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    DeletePublicKeyCommandInput,
    DeletePublicKeyCommandOutput,
    CloudFrontClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
export declare class DeletePublicKeyCommand extends DeletePublicKeyCommand_base {
  protected static __types: {
    api: {
      input: DeletePublicKeyRequest;
      output: {};
    };
    sdk: {
      input: DeletePublicKeyCommandInput;
      output: DeletePublicKeyCommandOutput;
    };
  };
}
