/**
 * simple-proxy.ts
 * Un proxy DHCP minimale che agisce come un mini-server DHCP completo
 * solo per i client PXE, per aggirare le protezioni di rete.
 */
import type { IDhcpOptions } from '../dhcpd-proxy//interfaces/i-pxe.js';
/**
 * La nostra unica funzione. Prende le opzioni e avvia il proxy.
 * @param options Le opzioni di configurazione PXE
 */
export declare function startSimpleProxy(options: IDhcpOptions): void;
