import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import {
  CloudFrontClientResolvedConfig,
  ServiceInputTypes,
  ServiceOutputTypes,
} from "../CloudFrontClient";
import {
  CopyDistributionRequest,
  CopyDistributionResult,
} from "../models/models_0";
export { __MetadataBearer };
export { $Command };
export interface CopyDistributionCommandInput extends CopyDistributionRequest {}
export interface CopyDistributionCommandOutput
  extends CopyDistributionResult,
    __MetadataBearer {}
declare const CopyDistributionCommand_base: {
  new (
    input: CopyDistributionCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    CopyDistributionCommandInput,
    CopyDistributionCommandOutput,
    CloudFrontClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  new (
    input: CopyDistributionCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    CopyDistributionCommandInput,
    CopyDistributionCommandOutput,
    CloudFrontClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
export declare class CopyDistributionCommand extends CopyDistributionCommand_base {
  protected static __types: {
    api: {
      input: CopyDistributionRequest;
      output: CopyDistributionResult;
    };
    sdk: {
      input: CopyDistributionCommandInput;
      output: CopyDistributionCommandOutput;
    };
  };
}
