/**
 * ./src/components/finished.tsx
 * penguins-eggs v.25.7.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
import React from 'react';
type FinishedProps = {
    hostName?: string;
    installationDevice?: string;
    message?: string;
    userName?: string;
};
export default function Finished({ hostName, installationDevice, message, userName }: FinishedProps): React.JSX.Element;
export {};
