/**
 * ./src/classes/families/cfs.ts (custom final steps)
 * penguins-eggs v.25.7.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
/**
 * cfs
 */
export default class CFS {
    /**
     * steps
     * @returns
     */
    steps(): Promise<string[]>;
}
