/**
 * ./src/classes/ovary.d/make-iso.ts
 * penguins-eggs v.25.7.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
import Ovary from '../ovary.js';
/**
 * makeIso
 * cmd: cmd 4 xorriso
 */
export declare function makeIso(this: Ovary, cmd: string, scriptOnly?: boolean): Promise<void>;
