/**
 * ./src/commands/export/deb.ts
 * penguins-eggs v.25.7.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
import { Command } from '@oclif/core';
import Tools from '../../classes/tools.js';
export default class ExportTarballs extends Command {
    static description: string;
    static examples: string[];
    static flags: {
        clean: import("@oclif/core/interfaces").BooleanFlag<boolean>;
        help: import("@oclif/core/interfaces").BooleanFlag<void>;
        verbose: import("@oclif/core/interfaces").BooleanFlag<boolean>;
    };
    clean: boolean;
    echo: {};
    Tu: Tools;
    user: string;
    verbose: boolean;
    /**
     *
     */
    run(): Promise<void>;
}
