import type { BuildMiddleware } from "@smithy/types";
/**
 * No-op middleware for runtimes outside of Node.js
 * @internal
 */
export declare const recursionDetectionMiddleware: () => BuildMiddleware<any, any>;
