import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import {
  CloudFrontClientResolvedConfig,
  ServiceInputTypes,
  ServiceOutputTypes,
} from "../CloudFrontClient";
import { DeleteKeyGroupRequest } from "../models/models_0";
export { __MetadataBearer };
export { $Command };
export interface DeleteKeyGroupCommandInput extends DeleteKeyGroupRequest {}
export interface DeleteKeyGroupCommandOutput extends __MetadataBearer {}
declare const DeleteKeyGroupCommand_base: {
  new (
    input: DeleteKeyGroupCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    DeleteKeyGroupCommandInput,
    DeleteKeyGroupCommandOutput,
    CloudFrontClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  new (
    input: DeleteKeyGroupCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    DeleteKeyGroupCommandInput,
    DeleteKeyGroupCommandOutput,
    CloudFrontClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
export declare class DeleteKeyGroupCommand extends DeleteKeyGroupCommand_base {
  protected static __types: {
    api: {
      input: DeleteKeyGroupRequest;
      output: {};
    };
    sdk: {
      input: DeleteKeyGroupCommandInput;
      output: DeleteKeyGroupCommandOutput;
    };
  };
}
