module.exports={A:{A:{"2":"K D E F A B 3C"},B:{"1":"Q","2":"0 1 2 3 4 5 6 7 8 9 C L M G N O P H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I"},C:{"2":"0 1 2 3 4 5 6 7 8 9 4C WC J cB K D E F A B C L M G N O P dB BB CB DB EB FB GB HB IB JB YC 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC cC 5C 6C 7C 8C","66":"KB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B XC 7B"},D:{"1":"jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B XC 7B YC 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q","2":"0 1 2 3 4 5 6 7 8 9 J cB K D E F A B C L M G N O P dB BB CB DB EB FB H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC cC","33":"GB HB IB JB KB eB fB gB hB iB"},E:{"2":"J cB K D E F A B C L M G 9C dC AD BD CD DD eC QC RC ED FD GD fC gC SC HD TC hC iC jC kC lC ID UC mC nC oC pC qC JD VC rC sC tC uC vC wC xC yC zC 0C KD"},F:{"1":"DB EB FB GB HB IB JB KB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC","2":"0 1 2 3 4 5 6 7 8 9 F B C DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LD MD ND OD QC 1C PD RC","33":"G N O P dB BB CB"},G:{"2":"E dC QD 2C RD SD TD UD VD WD XD YD ZD aD bD cD dD eD fD gD hD iD jD fC gC SC kD TC hC iC jC kC lC lD UC mC nC oC pC qC mD VC rC sC tC uC vC wC xC yC zC 0C"},H:{"2":"nD"},I:{"2":"WC J I oD pD qD rD 2C","33":"sD tD"},J:{"2":"D A"},K:{"2":"A B C H QC 1C RC"},L:{"2":"I"},M:{"2":"PC"},N:{"2":"A B"},O:{"2":"SC"},P:{"1":"uD vD wD xD yD eC zD 0D","2":"BB CB DB EB FB GB HB IB JB KB 1D 2D 3D TC UC VC 4D","33":"J"},Q:{"1":"5D"},R:{"2":"6D"},S:{"1":"7D","2":"8D"}},B:7,C:"Shadow DOM (deprecated V0 spec)",D:true};
