/**
 * ./src/interfaces/i-user.ts
 * penguins-eggs v.25.7.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
export interface ILuksPassphrase {
    confirm: string;
    passphrase: string;
}
