"use strict";

exports.rules = {
  // These are safe to use as long as the `"prettier/prettier"` rule from
  // eslint-plugin-prettier isn’t enabled.
  // These are also included in `"plugin:prettier/recommended"`:
  // https://github.com/prettier/eslint-plugin-prettier#recommended-configuration
  "arrow-body-style": 0,
  "prefer-arrow-callback": 0,
};
