import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import {
  CloudFrontClientResolvedConfig,
  ServiceInputTypes,
  ServiceOutputTypes,
} from "../CloudFrontClient";
import {
  GetAnycastIpListRequest,
  GetAnycastIpListResult,
} from "../models/models_0";
export { __MetadataBearer };
export { $Command };
export interface GetAnycastIpListCommandInput extends GetAnycastIpListRequest {}
export interface GetAnycastIpListCommandOutput
  extends GetAnycastIpListResult,
    __MetadataBearer {}
declare const GetAnycastIpListCommand_base: {
  new (
    input: GetAnycastIpListCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    GetAnycastIpListCommandInput,
    GetAnycastIpListCommandOutput,
    CloudFrontClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  new (
    input: GetAnycastIpListCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    GetAnycastIpListCommandInput,
    GetAnycastIpListCommandOutput,
    CloudFrontClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
export declare class GetAnycastIpListCommand extends GetAnycastIpListCommand_base {
  protected static __types: {
    api: {
      input: GetAnycastIpListRequest;
      output: GetAnycastIpListResult;
    };
    sdk: {
      input: GetAnycastIpListCommandInput;
      output: GetAnycastIpListCommandOutput;
    };
  };
}
