import type { UserAgentPair } from "@smithy/types";
/**
 * Returns the runtime name and version as a user agent pair.
 * @internal
 */
export declare const getRuntimeUserAgentPair: () => UserAgentPair;
