/**
 * Format whitespace in HTML.
 *
 * @param {Root} tree
 *   Tree.
 * @param {Options | null | undefined} [options]
 *   Configuration (optional).
 * @returns {undefined}
 *   Nothing.
 */
export function format(tree: Root, options?: Options | null | undefined): undefined;
import type { Root } from 'hast';
import type { Options } from './types.js';
//# sourceMappingURL=index.d.ts.map