import { Logger } from "@smithy/types";
export { Logger } from "@smithy/types";
export type LogLevel =
  | "all"
  | "trace"
  | "debug"
  | "log"
  | "info"
  | "warn"
  | "error"
  | "off";
export interface LoggerOptions {
  logger?: Logger;
  logLevel?: LogLevel;
}
