/**
 * ./src/commands/krill.ts
 * penguins-eggs v.25.11.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
import { Command } from '@oclif/core';
/**
 * Class Krill
 */
export default class KrillCommand extends Command {
    static description: string;
    static examples: string[];
    static flags: {
        btrfs: import("@oclif/core/interfaces").BooleanFlag<boolean>;
        chroot: import("@oclif/core/interfaces").BooleanFlag<boolean>;
        crypted: import("@oclif/core/interfaces").BooleanFlag<boolean>;
        domain: import("@oclif/core/interfaces").OptionFlag<string | undefined, import("@oclif/core/interfaces").CustomOptions>;
        halt: import("@oclif/core/interfaces").BooleanFlag<boolean>;
        help: import("@oclif/core/interfaces").BooleanFlag<void>;
        ip: import("@oclif/core/interfaces").BooleanFlag<boolean>;
        nointeractive: import("@oclif/core/interfaces").BooleanFlag<boolean>;
        none: import("@oclif/core/interfaces").BooleanFlag<boolean>;
        pve: import("@oclif/core/interfaces").BooleanFlag<boolean>;
        random: import("@oclif/core/interfaces").BooleanFlag<boolean>;
        replace: import("@oclif/core/interfaces").OptionFlag<string | undefined, import("@oclif/core/interfaces").CustomOptions>;
        small: import("@oclif/core/interfaces").BooleanFlag<boolean>;
        suspend: import("@oclif/core/interfaces").BooleanFlag<boolean>;
        testing: import("@oclif/core/interfaces").BooleanFlag<boolean>;
        unattended: import("@oclif/core/interfaces").BooleanFlag<boolean>;
        verbose: import("@oclif/core/interfaces").BooleanFlag<boolean>;
    };
    /**
     * Execute
     */
    run(): Promise<void>;
}
