/**
 * src/krill/modules/change-password.ts
 * penguins-eggs v.25.7.x / ecmascript 2020
 * REFACTORED: Uses "The SysUser Master" class.
 * Changes user password directly in /etc/shadow safely (No binaries, SELinux safe).
 */
import Sequence from '../sequence.js';
/**
 * changePassword
 * @param name - Username to update
 * @param newPassword - New plain text password
 */
export default function changePassword(this: Sequence, name?: string, newPassword?: string): Promise<void>;
