/**
 * ./src/commands/wardrobe/show.ts
 * penguins-eggs v.25.7.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
import { Command } from '@oclif/core';
/**
 *
 */
export default class Show extends Command {
    static args: {
        repo: import("@oclif/core/interfaces").Arg<string | undefined, Record<string, unknown>>;
    };
    static description: string;
    static example: string[];
    static flags: {
        help: import("@oclif/core/interfaces").BooleanFlag<void>;
        json: import("@oclif/core/interfaces").BooleanFlag<boolean>;
        verbose: import("@oclif/core/interfaces").BooleanFlag<boolean>;
        wardrobe: import("@oclif/core/interfaces").OptionFlag<string | undefined, import("@oclif/core/interfaces").CustomOptions>;
    };
    run(): Promise<void>;
}
