/**
 * ./src/classes/locales.ts
 * penguins-eggs v.25.7.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
export default class Locales {
    /**
     *
     */
    getDefault(): Promise<string>;
    /**
     * getEnabled
     */
    getEnabled(): Promise<string[]>;
    /**
     * getSupported
     */
    getSupported(): Promise<string[]>;
}
