/**
 * ./src/classes/ovary.d/make-squashfs.ts
 * penguins-eggs v.25.7.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
import Ovary from '../ovary.js';
/**
 * getStandardExclusions
 * returns a list of exclusions
 */
export declare function getStandardExclusions(ovary: Ovary, includeRootHome?: boolean): string[];
/**
 * squashFs: crea in live filesystem.squashfs
 */
export declare function makeSquashfs(this: Ovary, scriptOnly?: boolean, includeRootHome?: boolean): Promise<string>;
/**
 * Add or remove exclusion
 * @param add {boolean} true = add, false remove
 * @param exclusion {string} path to add/remove
 */
export declare function addExclusion(this: Ovary, exclusion: string): void;
