import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import {
  CloudFrontClientResolvedConfig,
  ServiceInputTypes,
  ServiceOutputTypes,
} from "../CloudFrontClient";
import {
  ListDistributionsByResponseHeadersPolicyIdRequest,
  ListDistributionsByResponseHeadersPolicyIdResult,
} from "../models/models_1";
export { __MetadataBearer };
export { $Command };
export interface ListDistributionsByResponseHeadersPolicyIdCommandInput
  extends ListDistributionsByResponseHeadersPolicyIdRequest {}
export interface ListDistributionsByResponseHeadersPolicyIdCommandOutput
  extends ListDistributionsByResponseHeadersPolicyIdResult,
    __MetadataBearer {}
declare const ListDistributionsByResponseHeadersPolicyIdCommand_base: {
  new (
    input: ListDistributionsByResponseHeadersPolicyIdCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    ListDistributionsByResponseHeadersPolicyIdCommandInput,
    ListDistributionsByResponseHeadersPolicyIdCommandOutput,
    CloudFrontClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  new (
    input: ListDistributionsByResponseHeadersPolicyIdCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    ListDistributionsByResponseHeadersPolicyIdCommandInput,
    ListDistributionsByResponseHeadersPolicyIdCommandOutput,
    CloudFrontClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
export declare class ListDistributionsByResponseHeadersPolicyIdCommand extends ListDistributionsByResponseHeadersPolicyIdCommand_base {
  protected static __types: {
    api: {
      input: ListDistributionsByResponseHeadersPolicyIdRequest;
      output: ListDistributionsByResponseHeadersPolicyIdResult;
    };
    sdk: {
      input: ListDistributionsByResponseHeadersPolicyIdCommandInput;
      output: ListDistributionsByResponseHeadersPolicyIdCommandOutput;
    };
  };
}
