module.exports={A:{A:{"1":"B","2":"K D E F A 3C"},B:{"1":"0 1 2 3 4 5 6 7 8 9 M G N O P Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I","129":"C L"},C:{"1":"0 1 2 3 4 5 6 7 8 9 yB zB 0B 1B 2B 3B 4B 5B 6B XC 7B YC 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC cC 5C 6C","2":"4C WC","260":"G N O P dB BB CB DB EB FB GB HB IB JB KB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB","804":"J cB K D E F A B C L M 7C 8C"},D:{"1":"0 1 2 3 4 5 6 7 8 9 4B 5B 6B XC 7B YC 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC cC","260":"zB 0B 1B 2B 3B","388":"eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB","1412":"G N O P dB BB CB DB EB FB GB HB IB JB KB","1956":"J cB K D E F A B C L M"},E:{"1":"gC SC HD TC hC iC jC kC lC ID UC mC nC oC pC qC JD VC rC sC tC uC vC wC xC yC zC 0C KD","129":"A B C L M G DD eC QC RC ED FD GD fC","1412":"K D E F BD CD","1956":"J cB 9C dC AD"},F:{"1":"0 1 2 3 4 5 6 7 8 9 rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB","2":"F LD MD","260":"mB nB oB pB qB","388":"G N O P dB BB CB DB EB FB GB HB IB JB KB eB fB gB hB iB jB kB lB","1796":"ND OD","1828":"B C QC 1C PD RC"},G:{"1":"gC SC kD TC hC iC jC kC lC lD UC mC nC oC pC qC mD VC rC sC tC uC vC wC xC yC zC 0C","129":"WD XD YD ZD aD bD cD dD eD fD gD hD iD jD fC","1412":"E SD TD UD VD","1956":"dC QD 2C RD"},H:{"1828":"nD"},I:{"1":"I","388":"sD tD","1956":"WC J oD pD qD rD 2C"},J:{"1412":"A","1924":"D"},K:{"1":"H","2":"A","1828":"B C QC 1C RC"},L:{"1":"I"},M:{"1":"PC"},N:{"1":"B","2":"A"},O:{"1":"SC"},P:{"1":"BB CB DB EB FB GB HB IB JB KB wD xD yD eC zD 0D 1D 2D 3D TC UC VC 4D","260":"uD vD","388":"J"},Q:{"1":"5D"},R:{"1":"6D"},S:{"1":"8D","260":"7D"}},B:4,C:"CSS3 Border images",D:true};
