import type { RuntimeConfigAwsCredentialIdentityProvider } from "@aws-sdk/types";
import type { FromLoginCredentialsInit } from "./types";
/**
 * Creates a credential provider that sources credentials from aws login cached tokens
 * @internal
 */
export declare const fromLoginCredentials: (init?: FromLoginCredentialsInit) => RuntimeConfigAwsCredentialIdentityProvider;
