/**
 * DON'T EDIT THIS FILE.
 * This file was generated by "scripts/update-lib-configs.js" script.
 */
"use strict"

module.exports = {
    plugins: ["es"],
    rules: {
        "es/no-accessor-properties": "error",
        "es/no-array-isarray": "error",
        "es/no-date-now": "error",
        "es/no-json": "error",
        "es/no-keyword-properties": "error",
        "es/no-object-defineproperties": "error",
        "es/no-object-defineproperty": "error",
        "es/no-object-freeze": "error",
        "es/no-object-getownpropertydescriptor": "error",
        "es/no-object-getownpropertynames": "error",
        "es/no-object-getprototypeof": "error",
        "es/no-object-isextensible": "error",
        "es/no-object-isfrozen": "error",
        "es/no-object-issealed": "error",
        "es/no-object-keys": "error",
        "es/no-object-preventextensions": "error",
        "es/no-object-seal": "error",
        "es/no-trailing-commas": "error",
    },
}
