module.exports={A:{A:{"2":"K D E F A B 3C"},B:{"1":"0 1 2 3 4 5 6 7 8 9 w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I","2":"C L M G N O P Q","578":"H R S T U V W X Y Z a b c","1602":"d e f g h i j k l m n o p q r s t u v"},C:{"2":"4C WC J cB K D E F A B C L M G N O P dB BB CB DB EB FB GB HB IB JB KB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B XC 7B YC 8B 7C 8C","194":"0 1 2 3 4 5 6 7 8 9 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB","4292":"YB ZB aB bB","16580":"I aC PC bC cC 5C 6C"},D:{"2":"J cB K D E F A B C L M G N O P dB BB CB DB EB FB GB HB IB JB KB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B XC 7B YC 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q","578":"H R S T U V W X Y Z a b c","1602":"d e f g h i j k l m n o p q r s t u v","2049":"0 1 2 3 4 5 6 7 8 9 w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC cC"},E:{"2":"J cB K D E F A B G 9C dC AD BD CD DD eC GD fC gC SC HD TC hC iC jC kC lC ID UC mC nC oC","322":"C L M QC RC ED FD pC qC JD VC rC sC tC uC vC","8452":"wC xC yC zC 0C KD"},F:{"2":"F B C G N O P dB BB CB DB EB FB GB HB IB JB KB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC LD MD ND OD QC 1C PD RC","578":"JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h","2049":"0 1 2 3 4 5 6 7 8 9 i j k l m n o p q r s t u v w x y z AB"},G:{"1":"wC xC yC zC 0C","2":"E dC QD 2C RD SD TD UD VD WD XD YD ZD aD bD cD dD eD fD gD hD iD jD fC gC SC kD TC hC iC jC kC lC lD UC mC nC oC","322":"pC qC mD VC rC sC tC uC vC"},H:{"2":"nD"},I:{"2":"WC J I oD pD qD rD 2C sD tD"},J:{"2":"D A"},K:{"2":"A B C QC 1C RC","2049":"H"},L:{"1":"I"},M:{"194":"PC"},N:{"2":"A B"},O:{"2":"SC"},P:{"1":"FB GB HB IB JB KB","2":"J BB CB DB EB uD vD wD xD yD eC zD 0D 1D 2D 3D TC UC VC 4D"},Q:{"2":"5D"},R:{"2":"6D"},S:{"2":"7D","194":"8D"}},B:5,C:"WebGPU",D:true};
