export declare const OAuth2ErrorCode: {
  readonly AUTHCODE_EXPIRED: "AUTHCODE_EXPIRED";
  readonly INSUFFICIENT_PERMISSIONS: "INSUFFICIENT_PERMISSIONS";
  readonly INVALID_REQUEST: "INVALID_REQUEST";
  readonly SERVER_ERROR: "server_error";
  readonly TOKEN_EXPIRED: "TOKEN_EXPIRED";
  readonly USER_CREDENTIALS_CHANGED: "USER_CREDENTIALS_CHANGED";
};
export type OAuth2ErrorCode =
  (typeof OAuth2ErrorCode)[keyof typeof OAuth2ErrorCode];
