/**
 * ./src/classes/network.ts
 * penguins-eggs v.25.7.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
import { Netmask } from 'netmask';
/**
 *
 */
export default class Network {
    address: string;
    cidr: string;
    family: string;
    internal: boolean;
    mac: string;
    netmask: string;
    o: Netmask;
    /**
     *
     */
    constructor();
    base(): string;
    bitmask(): void;
    broadcast(): string | undefined;
    contains(): (address: string | Netmask | number) => boolean;
    first(): string;
    forEach(): (cb: (ip: string, long: number, index: number) => void) => void;
    hostmask(): string;
    last(): string;
    maskLong(): number;
    netLong(): number;
    next(): (count?: number) => Netmask;
    size(): number;
    toString(): () => string;
}
