module.exports={A:{A:{"2":"K D E F A 3C","132":"B"},B:{"1":"C L M G N O P","4":"0 1 2 3 4 5 6 7 8 9 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I"},C:{"2":"4C WC 7C","4":"0 1 2 3 4 5 6 7 8 9 K D E F A B C L M G N O P dB BB CB DB EB FB GB HB IB JB KB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B XC 7B YC 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC cC 5C 6C","8":"J cB 8C"},D:{"2":"J cB K","4":"0 1 2 3 4 5 6 7 8 9 D E F A B C L M G N O P dB BB CB DB EB FB GB HB IB JB KB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B XC 7B YC 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC cC"},E:{"2":"J cB K D E F A B C L M G 9C dC AD BD CD DD eC QC RC ED FD GD fC gC SC HD TC hC iC jC kC lC ID UC mC nC oC pC qC JD VC rC sC tC uC vC wC xC yC zC 0C KD"},F:{"2":"F B C LD MD ND OD QC 1C PD RC","4":"0 1 2 3 4 5 6 7 8 9 G N O P dB BB CB DB EB FB GB HB IB JB KB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB"},G:{"2":"dC QD","4":"E 2C RD SD TD UD VD WD XD YD ZD aD bD cD dD eD fD gD hD iD jD fC gC SC kD TC hC iC jC kC lC lD UC mC nC oC pC qC mD VC rC sC tC uC vC wC xC yC zC 0C"},H:{"2":"nD"},I:{"2":"oD pD qD","4":"WC J I rD 2C sD tD"},J:{"2":"D","4":"A"},K:{"1":"C RC","2":"A B QC 1C","4":"H"},L:{"4":"I"},M:{"4":"PC"},N:{"1":"B","2":"A"},O:{"4":"SC"},P:{"4":"J BB CB DB EB FB GB HB IB JB KB uD vD wD xD yD eC zD 0D 1D 2D 3D TC UC VC 4D"},Q:{"4":"5D"},R:{"4":"6D"},S:{"4":"7D 8D"}},B:4,C:"DeviceOrientation & DeviceMotion events",D:true};
