export declare const SHA_256_HASH: {
    name: "SHA-256";
};
export declare const SHA_256_HMAC_ALGO: {
    name: "HMAC";
    hash: {
        name: "SHA-256";
    };
};
export declare const EMPTY_DATA_SHA_256: Uint8Array;
