import type { TokenIdentity } from "./identity";
import type { Provider } from "./util";
/**
 * @public
 *
 * An object representing temporary or permanent AWS token.
 *
 * @deprecated Use {@link TokenIdentity}
 */
export interface Token extends TokenIdentity {
}
/**
 * @public
 *
 * @deprecated Use {@link TokenIdentityProvider}
 */
export type TokenProvider = Provider<Token>;
