import { TypeRegistry } from "@smithy/core/schema";
import type { StaticErrorSchema, StaticOperationSchema, StaticStructureSchema } from "@smithy/types";
export declare var STSServiceException$: StaticErrorSchema;
export declare var ExpiredTokenException$: StaticErrorSchema;
export declare var IDPCommunicationErrorException$: StaticErrorSchema;
export declare var IDPRejectedClaimException$: StaticErrorSchema;
export declare var InvalidIdentityTokenException$: StaticErrorSchema;
export declare var MalformedPolicyDocumentException$: StaticErrorSchema;
export declare var PackedPolicyTooLargeException$: StaticErrorSchema;
export declare var RegionDisabledException$: StaticErrorSchema;
/**
 * TypeRegistry instances containing modeled errors.
 * @internal
 *
 */
export declare const errorTypeRegistries: TypeRegistry[];
export declare var AssumedRoleUser$: StaticStructureSchema;
export declare var AssumeRoleRequest$: StaticStructureSchema;
export declare var AssumeRoleResponse$: StaticStructureSchema;
export declare var AssumeRoleWithWebIdentityRequest$: StaticStructureSchema;
export declare var AssumeRoleWithWebIdentityResponse$: StaticStructureSchema;
export declare var Credentials$: StaticStructureSchema;
export declare var PolicyDescriptorType$: StaticStructureSchema;
export declare var ProvidedContext$: StaticStructureSchema;
export declare var Tag$: StaticStructureSchema;
export declare var AssumeRole$: StaticOperationSchema;
export declare var AssumeRoleWithWebIdentity$: StaticOperationSchema;
