module.exports={A:{A:{"2":"K D E F 3C","132":"A B"},B:{"132":"C L M G N O P","1028":"0 1 2 3 4 5 6 7 8 9 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I"},C:{"2":"4C WC J cB K D E F A B C L M G N O P dB BB CB DB EB FB GB HB IB JB KB eB fB gB 7C 8C","1028":"0 1 2 3 4 5 6 7 8 9 FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC cC 5C 6C","2564":"hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB","3076":"xB yB zB 0B 1B 2B 3B 4B 5B 6B XC 7B YC 8B 9B AC BC CC DC EC"},D:{"16":"J cB K D","132":"F A B C L M G N O P dB BB CB DB EB FB GB HB IB JB KB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B XC 7B","388":"E","1028":"0 1 2 3 4 5 6 7 8 9 YC 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC cC"},E:{"16":"J 9C dC","132":"cB K D E F A AD BD CD DD eC","1028":"B C L M G QC RC ED FD GD fC gC SC HD TC hC iC jC kC lC ID UC mC nC oC pC qC JD VC rC sC tC uC vC wC xC yC zC 0C KD"},F:{"2":"F B C LD MD ND OD QC 1C PD RC","132":"G N O P dB BB CB DB EB FB GB HB IB JB KB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB","1028":"0 1 2 3 4 5 6 7 8 9 wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB"},G:{"16":"dC QD 2C","132":"E RD SD TD UD VD WD XD YD","1028":"ZD aD bD cD dD eD fD gD hD iD jD fC gC SC kD TC hC iC jC kC lC lD UC mC nC oC pC qC mD VC rC sC tC uC vC wC xC yC zC 0C"},H:{"2":"nD"},I:{"132":"J rD 2C sD tD","292":"WC oD pD qD","1028":"I"},J:{"16":"D","132":"A"},K:{"2":"A B C QC 1C RC","1028":"H"},L:{"1028":"I"},M:{"1028":"PC"},N:{"132":"A B"},O:{"1028":"SC"},P:{"132":"J BB CB DB EB FB GB HB IB JB KB uD vD wD xD yD eC zD 0D 1D 2D 3D TC UC VC 4D"},Q:{"1028":"5D"},R:{"1028":"6D"},S:{"1028":"8D","2564":"7D"}},B:4,C:"DOMMatrix",D:true};
