/**
 * ./src/interfaces/i-app.ts
 * penguins-eggs v.25.7.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
export interface IApp {
    author: string;
    homepage: string;
    mail: string;
    name: string;
    version: string;
}
