module.exports={A:{A:{"2":"K D E F A B 3C"},B:{"2":"C L M G N O P","1025":"0 1 2 3 4 5 6 7 8 9 d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I","1537":"Q H R S T U V W X Y Z a b c"},C:{"2":"4C","932":"WC J cB K D E F A B C L M G N O P dB BB CB DB EB FB GB HB IB JB KB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B XC 7B YC 8B 9B AC BC 7C 8C","2308":"0 1 2 3 4 5 6 7 8 9 CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC cC 5C 6C"},D:{"2":"J cB K D E F A B C L M G N O P dB BB CB","545":"DB EB FB GB HB IB JB KB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB","1025":"0 1 2 3 4 5 6 7 8 9 d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC cC","1537":"uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B XC 7B YC 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R S T U V W X Y Z a b c"},E:{"1":"TC hC iC jC kC lC ID UC mC nC oC pC qC JD VC rC sC tC uC vC wC xC yC zC 0C KD","2":"J cB K 9C dC AD","516":"B C L M G QC RC ED FD GD fC gC SC HD","548":"F A DD eC","676":"D E BD CD"},F:{"2":"F B C LD MD ND OD QC 1C PD RC","513":"iB","545":"G N O P dB BB CB DB EB FB GB HB IB JB KB eB fB gB","1025":"0 1 2 3 4 5 6 7 8 9 e f g h i j k l m n o p q r s t u v w x y z AB","1537":"hB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d"},G:{"1":"TC hC iC jC kC lC lD UC mC nC oC pC qC mD VC rC sC tC uC vC wC xC yC zC 0C","2":"dC QD 2C RD SD","516":"hD iD jD fC gC SC kD","548":"VD WD XD YD ZD aD bD cD dD eD fD gD","676":"E TD UD"},H:{"2":"nD"},I:{"2":"WC J oD pD qD rD 2C","545":"sD tD","1025":"I"},J:{"2":"D","545":"A"},K:{"2":"A B C QC 1C RC","1025":"H"},L:{"1025":"I"},M:{"2308":"PC"},N:{"2":"A B"},O:{"1537":"SC"},P:{"545":"J","1025":"BB CB DB EB FB GB HB IB JB KB UC VC 4D","1537":"uD vD wD xD yD eC zD 0D 1D 2D 3D TC"},Q:{"1537":"5D"},R:{"1537":"6D"},S:{"932":"7D","2308":"8D"}},B:5,C:"Intrinsic & Extrinsic Sizing",D:true};
