import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import {
  CloudFrontClientResolvedConfig,
  ServiceInputTypes,
  ServiceOutputTypes,
} from "../CloudFrontClient";
import {
  CreateStreamingDistributionRequest,
  CreateStreamingDistributionResult,
} from "../models/models_0";
export { __MetadataBearer };
export { $Command };
export interface CreateStreamingDistributionCommandInput
  extends CreateStreamingDistributionRequest {}
export interface CreateStreamingDistributionCommandOutput
  extends CreateStreamingDistributionResult,
    __MetadataBearer {}
declare const CreateStreamingDistributionCommand_base: {
  new (
    input: CreateStreamingDistributionCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    CreateStreamingDistributionCommandInput,
    CreateStreamingDistributionCommandOutput,
    CloudFrontClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  new (
    input: CreateStreamingDistributionCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    CreateStreamingDistributionCommandInput,
    CreateStreamingDistributionCommandOutput,
    CloudFrontClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
export declare class CreateStreamingDistributionCommand extends CreateStreamingDistributionCommand_base {
  protected static __types: {
    api: {
      input: CreateStreamingDistributionRequest;
      output: CreateStreamingDistributionResult;
    };
    sdk: {
      input: CreateStreamingDistributionCommandInput;
      output: CreateStreamingDistributionCommandOutput;
    };
  };
}
