export declare const USER_AGENT = "user-agent";
export declare const X_AMZ_USER_AGENT = "x-amz-user-agent";
export declare const SPACE = " ";
export declare const UA_NAME_SEPARATOR = "/";
export declare const UA_NAME_ESCAPE_REGEX: RegExp;
export declare const UA_VALUE_ESCAPE_REGEX: RegExp;
export declare const UA_ESCAPE_CHAR = "-";
