/**
 * DON'T EDIT THIS FILE.
 * This file was generated automatically by 'scripts/update-lib-index.js'.
 */
"use strict"

const { printWarningOfDeprecatedConfig } = require("./utils")

module.exports = {
    configs: {
        "no-new-in-es5": require("./configs/no-new-in-es5"),
        "no-new-in-es2015": require("./configs/no-new-in-es2015"),
        "no-new-in-es2016": require("./configs/no-new-in-es2016"),
        "no-new-in-es2017": require("./configs/no-new-in-es2017"),
        "no-new-in-es2018": require("./configs/no-new-in-es2018"),
        "no-new-in-es2019": require("./configs/no-new-in-es2019"),
        "no-new-in-es2020": require("./configs/no-new-in-es2020"),
        "no-new-in-esnext": require("./configs/no-new-in-esnext"),
        "restrict-to-es3": require("./configs/restrict-to-es3"),
        "restrict-to-es5": require("./configs/restrict-to-es5"),
        "restrict-to-es2015": require("./configs/restrict-to-es2015"),
        "restrict-to-es2016": require("./configs/restrict-to-es2016"),
        "restrict-to-es2017": require("./configs/restrict-to-es2017"),
        "restrict-to-es2018": require("./configs/restrict-to-es2018"),
        "restrict-to-es2019": require("./configs/restrict-to-es2019"),
        get "no-5"() {
            printWarningOfDeprecatedConfig("no-5")
            return this["no-new-in-es5"]
        },
        get "no-2015"() {
            printWarningOfDeprecatedConfig("no-2015")
            return this["no-new-in-es2015"]
        },
        get "no-2016"() {
            printWarningOfDeprecatedConfig("no-2016")
            return this["no-new-in-es2016"]
        },
        get "no-2017"() {
            printWarningOfDeprecatedConfig("no-2017")
            return this["no-new-in-es2017"]
        },
        get "no-2018"() {
            printWarningOfDeprecatedConfig("no-2018")
            return this["no-new-in-es2018"]
        },
        get "no-2019"() {
            printWarningOfDeprecatedConfig("no-2019")
            return this["no-new-in-es2019"]
        },
    },
    rules: {
        "no-accessor-properties": require("./rules/no-accessor-properties"),
        "no-array-from": require("./rules/no-array-from"),
        "no-array-isarray": require("./rules/no-array-isarray"),
        "no-array-of": require("./rules/no-array-of"),
        "no-arrow-functions": require("./rules/no-arrow-functions"),
        "no-async-functions": require("./rules/no-async-functions"),
        "no-async-iteration": require("./rules/no-async-iteration"),
        "no-atomics": require("./rules/no-atomics"),
        "no-bigint": require("./rules/no-bigint"),
        "no-binary-numeric-literals": require("./rules/no-binary-numeric-literals"),
        "no-block-scoped-functions": require("./rules/no-block-scoped-functions"),
        "no-block-scoped-variables": require("./rules/no-block-scoped-variables"),
        "no-classes": require("./rules/no-classes"),
        "no-computed-properties": require("./rules/no-computed-properties"),
        "no-date-now": require("./rules/no-date-now"),
        "no-default-parameters": require("./rules/no-default-parameters"),
        "no-destructuring": require("./rules/no-destructuring"),
        "no-dynamic-import": require("./rules/no-dynamic-import"),
        "no-exponential-operators": require("./rules/no-exponential-operators"),
        "no-export-ns-from": require("./rules/no-export-ns-from"),
        "no-for-of-loops": require("./rules/no-for-of-loops"),
        "no-generators": require("./rules/no-generators"),
        "no-global-this": require("./rules/no-global-this"),
        "no-import-meta": require("./rules/no-import-meta"),
        "no-json": require("./rules/no-json"),
        "no-json-superset": require("./rules/no-json-superset"),
        "no-keyword-properties": require("./rules/no-keyword-properties"),
        "no-logical-assignment-operators": require("./rules/no-logical-assignment-operators"),
        "no-malformed-template-literals": require("./rules/no-malformed-template-literals"),
        "no-map": require("./rules/no-map"),
        "no-math-acosh": require("./rules/no-math-acosh"),
        "no-math-asinh": require("./rules/no-math-asinh"),
        "no-math-atanh": require("./rules/no-math-atanh"),
        "no-math-cbrt": require("./rules/no-math-cbrt"),
        "no-math-clz32": require("./rules/no-math-clz32"),
        "no-math-cosh": require("./rules/no-math-cosh"),
        "no-math-expm1": require("./rules/no-math-expm1"),
        "no-math-fround": require("./rules/no-math-fround"),
        "no-math-hypot": require("./rules/no-math-hypot"),
        "no-math-imul": require("./rules/no-math-imul"),
        "no-math-log1p": require("./rules/no-math-log1p"),
        "no-math-log2": require("./rules/no-math-log2"),
        "no-math-log10": require("./rules/no-math-log10"),
        "no-math-sign": require("./rules/no-math-sign"),
        "no-math-sinh": require("./rules/no-math-sinh"),
        "no-math-tanh": require("./rules/no-math-tanh"),
        "no-math-trunc": require("./rules/no-math-trunc"),
        "no-modules": require("./rules/no-modules"),
        "no-new-target": require("./rules/no-new-target"),
        "no-nullish-coalescing-operators": require("./rules/no-nullish-coalescing-operators"),
        "no-number-epsilon": require("./rules/no-number-epsilon"),
        "no-number-isfinite": require("./rules/no-number-isfinite"),
        "no-number-isinteger": require("./rules/no-number-isinteger"),
        "no-number-isnan": require("./rules/no-number-isnan"),
        "no-number-issafeinteger": require("./rules/no-number-issafeinteger"),
        "no-number-maxsafeinteger": require("./rules/no-number-maxsafeinteger"),
        "no-number-minsafeinteger": require("./rules/no-number-minsafeinteger"),
        "no-number-parsefloat": require("./rules/no-number-parsefloat"),
        "no-number-parseint": require("./rules/no-number-parseint"),
        "no-numeric-separators": require("./rules/no-numeric-separators"),
        "no-object-assign": require("./rules/no-object-assign"),
        "no-object-defineproperties": require("./rules/no-object-defineproperties"),
        "no-object-defineproperty": require("./rules/no-object-defineproperty"),
        "no-object-entries": require("./rules/no-object-entries"),
        "no-object-freeze": require("./rules/no-object-freeze"),
        "no-object-fromentries": require("./rules/no-object-fromentries"),
        "no-object-getownpropertydescriptor": require("./rules/no-object-getownpropertydescriptor"),
        "no-object-getownpropertydescriptors": require("./rules/no-object-getownpropertydescriptors"),
        "no-object-getownpropertynames": require("./rules/no-object-getownpropertynames"),
        "no-object-getownpropertysymbols": require("./rules/no-object-getownpropertysymbols"),
        "no-object-getprototypeof": require("./rules/no-object-getprototypeof"),
        "no-object-is": require("./rules/no-object-is"),
        "no-object-isextensible": require("./rules/no-object-isextensible"),
        "no-object-isfrozen": require("./rules/no-object-isfrozen"),
        "no-object-issealed": require("./rules/no-object-issealed"),
        "no-object-keys": require("./rules/no-object-keys"),
        "no-object-preventextensions": require("./rules/no-object-preventextensions"),
        "no-object-seal": require("./rules/no-object-seal"),
        "no-object-setprototypeof": require("./rules/no-object-setprototypeof"),
        "no-object-super-properties": require("./rules/no-object-super-properties"),
        "no-object-values": require("./rules/no-object-values"),
        "no-octal-numeric-literals": require("./rules/no-octal-numeric-literals"),
        "no-optional-catch-binding": require("./rules/no-optional-catch-binding"),
        "no-optional-chaining": require("./rules/no-optional-chaining"),
        "no-promise": require("./rules/no-promise"),
        "no-promise-all-settled": require("./rules/no-promise-all-settled"),
        "no-promise-any": require("./rules/no-promise-any"),
        "no-property-shorthands": require("./rules/no-property-shorthands"),
        "no-proxy": require("./rules/no-proxy"),
        "no-reflect": require("./rules/no-reflect"),
        "no-regexp-lookbehind-assertions": require("./rules/no-regexp-lookbehind-assertions"),
        "no-regexp-named-capture-groups": require("./rules/no-regexp-named-capture-groups"),
        "no-regexp-s-flag": require("./rules/no-regexp-s-flag"),
        "no-regexp-u-flag": require("./rules/no-regexp-u-flag"),
        "no-regexp-unicode-property-escapes": require("./rules/no-regexp-unicode-property-escapes"),
        "no-regexp-unicode-property-escapes-2019": require("./rules/no-regexp-unicode-property-escapes-2019"),
        "no-regexp-y-flag": require("./rules/no-regexp-y-flag"),
        "no-rest-parameters": require("./rules/no-rest-parameters"),
        "no-rest-spread-properties": require("./rules/no-rest-spread-properties"),
        "no-set": require("./rules/no-set"),
        "no-shared-array-buffer": require("./rules/no-shared-array-buffer"),
        "no-spread-elements": require("./rules/no-spread-elements"),
        "no-string-fromcodepoint": require("./rules/no-string-fromcodepoint"),
        "no-string-raw": require("./rules/no-string-raw"),
        "no-subclassing-builtins": require("./rules/no-subclassing-builtins"),
        "no-symbol": require("./rules/no-symbol"),
        "no-template-literals": require("./rules/no-template-literals"),
        "no-trailing-commas": require("./rules/no-trailing-commas"),
        "no-trailing-function-commas": require("./rules/no-trailing-function-commas"),
        "no-typed-arrays": require("./rules/no-typed-arrays"),
        "no-unicode-codepoint-escapes": require("./rules/no-unicode-codepoint-escapes"),
        "no-weak-map": require("./rules/no-weak-map"),
        "no-weak-set": require("./rules/no-weak-set"),
        "no-weakrefs": require("./rules/no-weakrefs"),
    },
}
