import { ExceptionOptionType as __ExceptionOptionType } from "@smithy/smithy-client";
import { CloudFrontServiceException as __BaseException } from "./CloudFrontServiceException";
export declare class AccessDenied extends __BaseException {
  readonly name: "AccessDenied";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(opts: __ExceptionOptionType<AccessDenied, __BaseException>);
}
export declare class IllegalUpdate extends __BaseException {
  readonly name: "IllegalUpdate";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(opts: __ExceptionOptionType<IllegalUpdate, __BaseException>);
}
export declare class InvalidArgument extends __BaseException {
  readonly name: "InvalidArgument";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(opts: __ExceptionOptionType<InvalidArgument, __BaseException>);
}
export declare class NoSuchDistribution extends __BaseException {
  readonly name: "NoSuchDistribution";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(opts: __ExceptionOptionType<NoSuchDistribution, __BaseException>);
}
export declare class TooManyDistributionCNAMEs extends __BaseException {
  readonly name: "TooManyDistributionCNAMEs";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<TooManyDistributionCNAMEs, __BaseException>
  );
}
export declare class EntityLimitExceeded extends __BaseException {
  readonly name: "EntityLimitExceeded";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<EntityLimitExceeded, __BaseException>
  );
}
export declare class EntityNotFound extends __BaseException {
  readonly name: "EntityNotFound";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(opts: __ExceptionOptionType<EntityNotFound, __BaseException>);
}
export declare class InvalidIfMatchVersion extends __BaseException {
  readonly name: "InvalidIfMatchVersion";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<InvalidIfMatchVersion, __BaseException>
  );
}
export declare class PreconditionFailed extends __BaseException {
  readonly name: "PreconditionFailed";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(opts: __ExceptionOptionType<PreconditionFailed, __BaseException>);
}
export declare class BatchTooLarge extends __BaseException {
  readonly name: "BatchTooLarge";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(opts: __ExceptionOptionType<BatchTooLarge, __BaseException>);
}
export declare class CachePolicyAlreadyExists extends __BaseException {
  readonly name: "CachePolicyAlreadyExists";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<CachePolicyAlreadyExists, __BaseException>
  );
}
export declare class CachePolicyInUse extends __BaseException {
  readonly name: "CachePolicyInUse";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(opts: __ExceptionOptionType<CachePolicyInUse, __BaseException>);
}
export declare class CannotChangeImmutablePublicKeyFields extends __BaseException {
  readonly name: "CannotChangeImmutablePublicKeyFields";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      CannotChangeImmutablePublicKeyFields,
      __BaseException
    >
  );
}
export declare class CannotDeleteEntityWhileInUse extends __BaseException {
  readonly name: "CannotDeleteEntityWhileInUse";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<CannotDeleteEntityWhileInUse, __BaseException>
  );
}
export declare class CannotUpdateEntityWhileInUse extends __BaseException {
  readonly name: "CannotUpdateEntityWhileInUse";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<CannotUpdateEntityWhileInUse, __BaseException>
  );
}
export declare class CNAMEAlreadyExists extends __BaseException {
  readonly name: "CNAMEAlreadyExists";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(opts: __ExceptionOptionType<CNAMEAlreadyExists, __BaseException>);
}
export declare class DistributionAlreadyExists extends __BaseException {
  readonly name: "DistributionAlreadyExists";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<DistributionAlreadyExists, __BaseException>
  );
}
export declare class IllegalFieldLevelEncryptionConfigAssociationWithCacheBehavior extends __BaseException {
  readonly name: "IllegalFieldLevelEncryptionConfigAssociationWithCacheBehavior";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      IllegalFieldLevelEncryptionConfigAssociationWithCacheBehavior,
      __BaseException
    >
  );
}
export declare class InconsistentQuantities extends __BaseException {
  readonly name: "InconsistentQuantities";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<InconsistentQuantities, __BaseException>
  );
}
export declare class InvalidDefaultRootObject extends __BaseException {
  readonly name: "InvalidDefaultRootObject";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<InvalidDefaultRootObject, __BaseException>
  );
}
export declare class InvalidErrorCode extends __BaseException {
  readonly name: "InvalidErrorCode";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(opts: __ExceptionOptionType<InvalidErrorCode, __BaseException>);
}
export declare class InvalidForwardCookies extends __BaseException {
  readonly name: "InvalidForwardCookies";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<InvalidForwardCookies, __BaseException>
  );
}
export declare class InvalidFunctionAssociation extends __BaseException {
  readonly name: "InvalidFunctionAssociation";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<InvalidFunctionAssociation, __BaseException>
  );
}
export declare class InvalidGeoRestrictionParameter extends __BaseException {
  readonly name: "InvalidGeoRestrictionParameter";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<InvalidGeoRestrictionParameter, __BaseException>
  );
}
export declare class InvalidHeadersForS3Origin extends __BaseException {
  readonly name: "InvalidHeadersForS3Origin";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<InvalidHeadersForS3Origin, __BaseException>
  );
}
export declare class InvalidLambdaFunctionAssociation extends __BaseException {
  readonly name: "InvalidLambdaFunctionAssociation";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      InvalidLambdaFunctionAssociation,
      __BaseException
    >
  );
}
export declare class InvalidLocationCode extends __BaseException {
  readonly name: "InvalidLocationCode";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<InvalidLocationCode, __BaseException>
  );
}
export declare class InvalidMinimumProtocolVersion extends __BaseException {
  readonly name: "InvalidMinimumProtocolVersion";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<InvalidMinimumProtocolVersion, __BaseException>
  );
}
export declare class InvalidOrigin extends __BaseException {
  readonly name: "InvalidOrigin";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(opts: __ExceptionOptionType<InvalidOrigin, __BaseException>);
}
export declare class InvalidOriginAccessControl extends __BaseException {
  readonly name: "InvalidOriginAccessControl";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<InvalidOriginAccessControl, __BaseException>
  );
}
export declare class InvalidOriginAccessIdentity extends __BaseException {
  readonly name: "InvalidOriginAccessIdentity";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<InvalidOriginAccessIdentity, __BaseException>
  );
}
export declare class InvalidOriginKeepaliveTimeout extends __BaseException {
  readonly name: "InvalidOriginKeepaliveTimeout";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<InvalidOriginKeepaliveTimeout, __BaseException>
  );
}
export declare class InvalidOriginReadTimeout extends __BaseException {
  readonly name: "InvalidOriginReadTimeout";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<InvalidOriginReadTimeout, __BaseException>
  );
}
export declare class InvalidProtocolSettings extends __BaseException {
  readonly name: "InvalidProtocolSettings";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<InvalidProtocolSettings, __BaseException>
  );
}
export declare class InvalidQueryStringParameters extends __BaseException {
  readonly name: "InvalidQueryStringParameters";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<InvalidQueryStringParameters, __BaseException>
  );
}
export declare class InvalidRelativePath extends __BaseException {
  readonly name: "InvalidRelativePath";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<InvalidRelativePath, __BaseException>
  );
}
export declare class InvalidRequiredProtocol extends __BaseException {
  readonly name: "InvalidRequiredProtocol";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<InvalidRequiredProtocol, __BaseException>
  );
}
export declare class InvalidResponseCode extends __BaseException {
  readonly name: "InvalidResponseCode";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<InvalidResponseCode, __BaseException>
  );
}
export declare class InvalidTTLOrder extends __BaseException {
  readonly name: "InvalidTTLOrder";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(opts: __ExceptionOptionType<InvalidTTLOrder, __BaseException>);
}
export declare class InvalidViewerCertificate extends __BaseException {
  readonly name: "InvalidViewerCertificate";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<InvalidViewerCertificate, __BaseException>
  );
}
export declare class InvalidWebACLId extends __BaseException {
  readonly name: "InvalidWebACLId";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(opts: __ExceptionOptionType<InvalidWebACLId, __BaseException>);
}
export declare class MissingBody extends __BaseException {
  readonly name: "MissingBody";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(opts: __ExceptionOptionType<MissingBody, __BaseException>);
}
export declare class NoSuchCachePolicy extends __BaseException {
  readonly name: "NoSuchCachePolicy";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(opts: __ExceptionOptionType<NoSuchCachePolicy, __BaseException>);
}
export declare class NoSuchFieldLevelEncryptionConfig extends __BaseException {
  readonly name: "NoSuchFieldLevelEncryptionConfig";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      NoSuchFieldLevelEncryptionConfig,
      __BaseException
    >
  );
}
export declare class NoSuchOrigin extends __BaseException {
  readonly name: "NoSuchOrigin";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(opts: __ExceptionOptionType<NoSuchOrigin, __BaseException>);
}
export declare class NoSuchOriginRequestPolicy extends __BaseException {
  readonly name: "NoSuchOriginRequestPolicy";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<NoSuchOriginRequestPolicy, __BaseException>
  );
}
export declare class NoSuchRealtimeLogConfig extends __BaseException {
  readonly name: "NoSuchRealtimeLogConfig";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<NoSuchRealtimeLogConfig, __BaseException>
  );
}
export declare class NoSuchResponseHeadersPolicy extends __BaseException {
  readonly name: "NoSuchResponseHeadersPolicy";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<NoSuchResponseHeadersPolicy, __BaseException>
  );
}
export declare class RealtimeLogConfigOwnerMismatch extends __BaseException {
  readonly name: "RealtimeLogConfigOwnerMismatch";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<RealtimeLogConfigOwnerMismatch, __BaseException>
  );
}
export declare class TooManyCacheBehaviors extends __BaseException {
  readonly name: "TooManyCacheBehaviors";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<TooManyCacheBehaviors, __BaseException>
  );
}
export declare class TooManyCertificates extends __BaseException {
  readonly name: "TooManyCertificates";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<TooManyCertificates, __BaseException>
  );
}
export declare class TooManyCookieNamesInWhiteList extends __BaseException {
  readonly name: "TooManyCookieNamesInWhiteList";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<TooManyCookieNamesInWhiteList, __BaseException>
  );
}
export declare class TooManyDistributions extends __BaseException {
  readonly name: "TooManyDistributions";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<TooManyDistributions, __BaseException>
  );
}
export declare class TooManyDistributionsAssociatedToCachePolicy extends __BaseException {
  readonly name: "TooManyDistributionsAssociatedToCachePolicy";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      TooManyDistributionsAssociatedToCachePolicy,
      __BaseException
    >
  );
}
export declare class TooManyDistributionsAssociatedToFieldLevelEncryptionConfig extends __BaseException {
  readonly name: "TooManyDistributionsAssociatedToFieldLevelEncryptionConfig";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      TooManyDistributionsAssociatedToFieldLevelEncryptionConfig,
      __BaseException
    >
  );
}
export declare class TooManyDistributionsAssociatedToKeyGroup extends __BaseException {
  readonly name: "TooManyDistributionsAssociatedToKeyGroup";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      TooManyDistributionsAssociatedToKeyGroup,
      __BaseException
    >
  );
}
export declare class TooManyDistributionsAssociatedToOriginAccessControl extends __BaseException {
  readonly name: "TooManyDistributionsAssociatedToOriginAccessControl";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      TooManyDistributionsAssociatedToOriginAccessControl,
      __BaseException
    >
  );
}
export declare class TooManyDistributionsAssociatedToOriginRequestPolicy extends __BaseException {
  readonly name: "TooManyDistributionsAssociatedToOriginRequestPolicy";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      TooManyDistributionsAssociatedToOriginRequestPolicy,
      __BaseException
    >
  );
}
export declare class TooManyDistributionsAssociatedToResponseHeadersPolicy extends __BaseException {
  readonly name: "TooManyDistributionsAssociatedToResponseHeadersPolicy";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      TooManyDistributionsAssociatedToResponseHeadersPolicy,
      __BaseException
    >
  );
}
export declare class TooManyDistributionsWithFunctionAssociations extends __BaseException {
  readonly name: "TooManyDistributionsWithFunctionAssociations";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      TooManyDistributionsWithFunctionAssociations,
      __BaseException
    >
  );
}
export declare class TooManyDistributionsWithLambdaAssociations extends __BaseException {
  readonly name: "TooManyDistributionsWithLambdaAssociations";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      TooManyDistributionsWithLambdaAssociations,
      __BaseException
    >
  );
}
export declare class TooManyDistributionsWithSingleFunctionARN extends __BaseException {
  readonly name: "TooManyDistributionsWithSingleFunctionARN";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      TooManyDistributionsWithSingleFunctionARN,
      __BaseException
    >
  );
}
export declare class TooManyFunctionAssociations extends __BaseException {
  readonly name: "TooManyFunctionAssociations";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<TooManyFunctionAssociations, __BaseException>
  );
}
export declare class TooManyHeadersInForwardedValues extends __BaseException {
  readonly name: "TooManyHeadersInForwardedValues";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      TooManyHeadersInForwardedValues,
      __BaseException
    >
  );
}
export declare class TooManyKeyGroupsAssociatedToDistribution extends __BaseException {
  readonly name: "TooManyKeyGroupsAssociatedToDistribution";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      TooManyKeyGroupsAssociatedToDistribution,
      __BaseException
    >
  );
}
export declare class TooManyLambdaFunctionAssociations extends __BaseException {
  readonly name: "TooManyLambdaFunctionAssociations";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      TooManyLambdaFunctionAssociations,
      __BaseException
    >
  );
}
export declare class TooManyOriginCustomHeaders extends __BaseException {
  readonly name: "TooManyOriginCustomHeaders";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<TooManyOriginCustomHeaders, __BaseException>
  );
}
export declare class TooManyOriginGroupsPerDistribution extends __BaseException {
  readonly name: "TooManyOriginGroupsPerDistribution";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      TooManyOriginGroupsPerDistribution,
      __BaseException
    >
  );
}
export declare class TooManyOrigins extends __BaseException {
  readonly name: "TooManyOrigins";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(opts: __ExceptionOptionType<TooManyOrigins, __BaseException>);
}
export declare class TooManyQueryStringParameters extends __BaseException {
  readonly name: "TooManyQueryStringParameters";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<TooManyQueryStringParameters, __BaseException>
  );
}
export declare class TooManyTrustedSigners extends __BaseException {
  readonly name: "TooManyTrustedSigners";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<TooManyTrustedSigners, __BaseException>
  );
}
export declare class TrustedKeyGroupDoesNotExist extends __BaseException {
  readonly name: "TrustedKeyGroupDoesNotExist";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<TrustedKeyGroupDoesNotExist, __BaseException>
  );
}
export declare class TrustedSignerDoesNotExist extends __BaseException {
  readonly name: "TrustedSignerDoesNotExist";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<TrustedSignerDoesNotExist, __BaseException>
  );
}
export declare class EntityAlreadyExists extends __BaseException {
  readonly name: "EntityAlreadyExists";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<EntityAlreadyExists, __BaseException>
  );
}
export declare class InvalidTagging extends __BaseException {
  readonly name: "InvalidTagging";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(opts: __ExceptionOptionType<InvalidTagging, __BaseException>);
}
export declare class UnsupportedOperation extends __BaseException {
  readonly name: "UnsupportedOperation";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<UnsupportedOperation, __BaseException>
  );
}
export declare class TooManyCachePolicies extends __BaseException {
  readonly name: "TooManyCachePolicies";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<TooManyCachePolicies, __BaseException>
  );
}
export declare class TooManyCookiesInCachePolicy extends __BaseException {
  readonly name: "TooManyCookiesInCachePolicy";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<TooManyCookiesInCachePolicy, __BaseException>
  );
}
export declare class TooManyHeadersInCachePolicy extends __BaseException {
  readonly name: "TooManyHeadersInCachePolicy";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<TooManyHeadersInCachePolicy, __BaseException>
  );
}
export declare class TooManyQueryStringsInCachePolicy extends __BaseException {
  readonly name: "TooManyQueryStringsInCachePolicy";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      TooManyQueryStringsInCachePolicy,
      __BaseException
    >
  );
}
export declare class CloudFrontOriginAccessIdentityAlreadyExists extends __BaseException {
  readonly name: "CloudFrontOriginAccessIdentityAlreadyExists";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      CloudFrontOriginAccessIdentityAlreadyExists,
      __BaseException
    >
  );
}
export declare class TooManyCloudFrontOriginAccessIdentities extends __BaseException {
  readonly name: "TooManyCloudFrontOriginAccessIdentities";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      TooManyCloudFrontOriginAccessIdentities,
      __BaseException
    >
  );
}
export declare class EntitySizeLimitExceeded extends __BaseException {
  readonly name: "EntitySizeLimitExceeded";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<EntitySizeLimitExceeded, __BaseException>
  );
}
export declare class ContinuousDeploymentPolicyAlreadyExists extends __BaseException {
  readonly name: "ContinuousDeploymentPolicyAlreadyExists";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      ContinuousDeploymentPolicyAlreadyExists,
      __BaseException
    >
  );
}
export declare class StagingDistributionInUse extends __BaseException {
  readonly name: "StagingDistributionInUse";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<StagingDistributionInUse, __BaseException>
  );
}
export declare class TooManyContinuousDeploymentPolicies extends __BaseException {
  readonly name: "TooManyContinuousDeploymentPolicies";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      TooManyContinuousDeploymentPolicies,
      __BaseException
    >
  );
}
export declare class ContinuousDeploymentPolicyInUse extends __BaseException {
  readonly name: "ContinuousDeploymentPolicyInUse";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      ContinuousDeploymentPolicyInUse,
      __BaseException
    >
  );
}
export declare class IllegalOriginAccessConfiguration extends __BaseException {
  readonly name: "IllegalOriginAccessConfiguration";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      IllegalOriginAccessConfiguration,
      __BaseException
    >
  );
}
export declare class InvalidDomainNameForOriginAccessControl extends __BaseException {
  readonly name: "InvalidDomainNameForOriginAccessControl";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      InvalidDomainNameForOriginAccessControl,
      __BaseException
    >
  );
}
export declare class NoSuchContinuousDeploymentPolicy extends __BaseException {
  readonly name: "NoSuchContinuousDeploymentPolicy";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      NoSuchContinuousDeploymentPolicy,
      __BaseException
    >
  );
}
export declare class InvalidAssociation extends __BaseException {
  readonly name: "InvalidAssociation";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(opts: __ExceptionOptionType<InvalidAssociation, __BaseException>);
}
export declare class FieldLevelEncryptionConfigAlreadyExists extends __BaseException {
  readonly name: "FieldLevelEncryptionConfigAlreadyExists";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      FieldLevelEncryptionConfigAlreadyExists,
      __BaseException
    >
  );
}
export declare class NoSuchFieldLevelEncryptionProfile extends __BaseException {
  readonly name: "NoSuchFieldLevelEncryptionProfile";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      NoSuchFieldLevelEncryptionProfile,
      __BaseException
    >
  );
}
export declare class QueryArgProfileEmpty extends __BaseException {
  readonly name: "QueryArgProfileEmpty";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<QueryArgProfileEmpty, __BaseException>
  );
}
export declare class TooManyFieldLevelEncryptionConfigs extends __BaseException {
  readonly name: "TooManyFieldLevelEncryptionConfigs";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      TooManyFieldLevelEncryptionConfigs,
      __BaseException
    >
  );
}
export declare class TooManyFieldLevelEncryptionContentTypeProfiles extends __BaseException {
  readonly name: "TooManyFieldLevelEncryptionContentTypeProfiles";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      TooManyFieldLevelEncryptionContentTypeProfiles,
      __BaseException
    >
  );
}
export declare class TooManyFieldLevelEncryptionQueryArgProfiles extends __BaseException {
  readonly name: "TooManyFieldLevelEncryptionQueryArgProfiles";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      TooManyFieldLevelEncryptionQueryArgProfiles,
      __BaseException
    >
  );
}
export declare class FieldLevelEncryptionProfileAlreadyExists extends __BaseException {
  readonly name: "FieldLevelEncryptionProfileAlreadyExists";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      FieldLevelEncryptionProfileAlreadyExists,
      __BaseException
    >
  );
}
export declare class FieldLevelEncryptionProfileSizeExceeded extends __BaseException {
  readonly name: "FieldLevelEncryptionProfileSizeExceeded";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      FieldLevelEncryptionProfileSizeExceeded,
      __BaseException
    >
  );
}
export declare class NoSuchPublicKey extends __BaseException {
  readonly name: "NoSuchPublicKey";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(opts: __ExceptionOptionType<NoSuchPublicKey, __BaseException>);
}
export declare class TooManyFieldLevelEncryptionEncryptionEntities extends __BaseException {
  readonly name: "TooManyFieldLevelEncryptionEncryptionEntities";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      TooManyFieldLevelEncryptionEncryptionEntities,
      __BaseException
    >
  );
}
export declare class TooManyFieldLevelEncryptionFieldPatterns extends __BaseException {
  readonly name: "TooManyFieldLevelEncryptionFieldPatterns";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      TooManyFieldLevelEncryptionFieldPatterns,
      __BaseException
    >
  );
}
export declare class TooManyFieldLevelEncryptionProfiles extends __BaseException {
  readonly name: "TooManyFieldLevelEncryptionProfiles";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      TooManyFieldLevelEncryptionProfiles,
      __BaseException
    >
  );
}
export declare class FunctionAlreadyExists extends __BaseException {
  readonly name: "FunctionAlreadyExists";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<FunctionAlreadyExists, __BaseException>
  );
}
export declare class FunctionSizeLimitExceeded extends __BaseException {
  readonly name: "FunctionSizeLimitExceeded";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<FunctionSizeLimitExceeded, __BaseException>
  );
}
export declare class TooManyFunctions extends __BaseException {
  readonly name: "TooManyFunctions";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(opts: __ExceptionOptionType<TooManyFunctions, __BaseException>);
}
export declare class TooManyInvalidationsInProgress extends __BaseException {
  readonly name: "TooManyInvalidationsInProgress";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<TooManyInvalidationsInProgress, __BaseException>
  );
}
export declare class KeyGroupAlreadyExists extends __BaseException {
  readonly name: "KeyGroupAlreadyExists";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<KeyGroupAlreadyExists, __BaseException>
  );
}
export declare class TooManyKeyGroups extends __BaseException {
  readonly name: "TooManyKeyGroups";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(opts: __ExceptionOptionType<TooManyKeyGroups, __BaseException>);
}
export declare class TooManyPublicKeysInKeyGroup extends __BaseException {
  readonly name: "TooManyPublicKeysInKeyGroup";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<TooManyPublicKeysInKeyGroup, __BaseException>
  );
}
export declare class MonitoringSubscriptionAlreadyExists extends __BaseException {
  readonly name: "MonitoringSubscriptionAlreadyExists";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      MonitoringSubscriptionAlreadyExists,
      __BaseException
    >
  );
}
export declare class OriginAccessControlAlreadyExists extends __BaseException {
  readonly name: "OriginAccessControlAlreadyExists";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      OriginAccessControlAlreadyExists,
      __BaseException
    >
  );
}
export declare class TooManyOriginAccessControls extends __BaseException {
  readonly name: "TooManyOriginAccessControls";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<TooManyOriginAccessControls, __BaseException>
  );
}
export declare class OriginRequestPolicyAlreadyExists extends __BaseException {
  readonly name: "OriginRequestPolicyAlreadyExists";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      OriginRequestPolicyAlreadyExists,
      __BaseException
    >
  );
}
export declare class TooManyCookiesInOriginRequestPolicy extends __BaseException {
  readonly name: "TooManyCookiesInOriginRequestPolicy";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      TooManyCookiesInOriginRequestPolicy,
      __BaseException
    >
  );
}
export declare class TooManyHeadersInOriginRequestPolicy extends __BaseException {
  readonly name: "TooManyHeadersInOriginRequestPolicy";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      TooManyHeadersInOriginRequestPolicy,
      __BaseException
    >
  );
}
export declare class TooManyOriginRequestPolicies extends __BaseException {
  readonly name: "TooManyOriginRequestPolicies";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<TooManyOriginRequestPolicies, __BaseException>
  );
}
export declare class TooManyQueryStringsInOriginRequestPolicy extends __BaseException {
  readonly name: "TooManyQueryStringsInOriginRequestPolicy";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      TooManyQueryStringsInOriginRequestPolicy,
      __BaseException
    >
  );
}
export declare class PublicKeyAlreadyExists extends __BaseException {
  readonly name: "PublicKeyAlreadyExists";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<PublicKeyAlreadyExists, __BaseException>
  );
}
export declare class TooManyPublicKeys extends __BaseException {
  readonly name: "TooManyPublicKeys";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(opts: __ExceptionOptionType<TooManyPublicKeys, __BaseException>);
}
export declare class RealtimeLogConfigAlreadyExists extends __BaseException {
  readonly name: "RealtimeLogConfigAlreadyExists";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<RealtimeLogConfigAlreadyExists, __BaseException>
  );
}
export declare class TooManyRealtimeLogConfigs extends __BaseException {
  readonly name: "TooManyRealtimeLogConfigs";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<TooManyRealtimeLogConfigs, __BaseException>
  );
}
export declare class ResponseHeadersPolicyAlreadyExists extends __BaseException {
  readonly name: "ResponseHeadersPolicyAlreadyExists";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      ResponseHeadersPolicyAlreadyExists,
      __BaseException
    >
  );
}
export declare class TooLongCSPInResponseHeadersPolicy extends __BaseException {
  readonly name: "TooLongCSPInResponseHeadersPolicy";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      TooLongCSPInResponseHeadersPolicy,
      __BaseException
    >
  );
}
export declare class TooManyCustomHeadersInResponseHeadersPolicy extends __BaseException {
  readonly name: "TooManyCustomHeadersInResponseHeadersPolicy";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      TooManyCustomHeadersInResponseHeadersPolicy,
      __BaseException
    >
  );
}
export declare class TooManyRemoveHeadersInResponseHeadersPolicy extends __BaseException {
  readonly name: "TooManyRemoveHeadersInResponseHeadersPolicy";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      TooManyRemoveHeadersInResponseHeadersPolicy,
      __BaseException
    >
  );
}
export declare class TooManyResponseHeadersPolicies extends __BaseException {
  readonly name: "TooManyResponseHeadersPolicies";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<TooManyResponseHeadersPolicies, __BaseException>
  );
}
export declare class StreamingDistributionAlreadyExists extends __BaseException {
  readonly name: "StreamingDistributionAlreadyExists";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      StreamingDistributionAlreadyExists,
      __BaseException
    >
  );
}
export declare class TooManyStreamingDistributionCNAMEs extends __BaseException {
  readonly name: "TooManyStreamingDistributionCNAMEs";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      TooManyStreamingDistributionCNAMEs,
      __BaseException
    >
  );
}
export declare class TooManyStreamingDistributions extends __BaseException {
  readonly name: "TooManyStreamingDistributions";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<TooManyStreamingDistributions, __BaseException>
  );
}
export declare class IllegalDelete extends __BaseException {
  readonly name: "IllegalDelete";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(opts: __ExceptionOptionType<IllegalDelete, __BaseException>);
}
export declare class CloudFrontOriginAccessIdentityInUse extends __BaseException {
  readonly name: "CloudFrontOriginAccessIdentityInUse";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      CloudFrontOriginAccessIdentityInUse,
      __BaseException
    >
  );
}
export declare class NoSuchCloudFrontOriginAccessIdentity extends __BaseException {
  readonly name: "NoSuchCloudFrontOriginAccessIdentity";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      NoSuchCloudFrontOriginAccessIdentity,
      __BaseException
    >
  );
}
export declare class ResourceNotDisabled extends __BaseException {
  readonly name: "ResourceNotDisabled";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<ResourceNotDisabled, __BaseException>
  );
}
export declare class DistributionNotDisabled extends __BaseException {
  readonly name: "DistributionNotDisabled";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<DistributionNotDisabled, __BaseException>
  );
}
export declare class ResourceInUse extends __BaseException {
  readonly name: "ResourceInUse";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(opts: __ExceptionOptionType<ResourceInUse, __BaseException>);
}
export declare class FieldLevelEncryptionConfigInUse extends __BaseException {
  readonly name: "FieldLevelEncryptionConfigInUse";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      FieldLevelEncryptionConfigInUse,
      __BaseException
    >
  );
}
export declare class FieldLevelEncryptionProfileInUse extends __BaseException {
  readonly name: "FieldLevelEncryptionProfileInUse";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      FieldLevelEncryptionProfileInUse,
      __BaseException
    >
  );
}
export declare class FunctionInUse extends __BaseException {
  readonly name: "FunctionInUse";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(opts: __ExceptionOptionType<FunctionInUse, __BaseException>);
}
export declare class NoSuchFunctionExists extends __BaseException {
  readonly name: "NoSuchFunctionExists";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<NoSuchFunctionExists, __BaseException>
  );
}
export declare class NoSuchResource extends __BaseException {
  readonly name: "NoSuchResource";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(opts: __ExceptionOptionType<NoSuchResource, __BaseException>);
}
export declare class NoSuchMonitoringSubscription extends __BaseException {
  readonly name: "NoSuchMonitoringSubscription";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<NoSuchMonitoringSubscription, __BaseException>
  );
}
export declare class NoSuchOriginAccessControl extends __BaseException {
  readonly name: "NoSuchOriginAccessControl";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<NoSuchOriginAccessControl, __BaseException>
  );
}
export declare class OriginAccessControlInUse extends __BaseException {
  readonly name: "OriginAccessControlInUse";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<OriginAccessControlInUse, __BaseException>
  );
}
export declare class OriginRequestPolicyInUse extends __BaseException {
  readonly name: "OriginRequestPolicyInUse";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<OriginRequestPolicyInUse, __BaseException>
  );
}
export declare class PublicKeyInUse extends __BaseException {
  readonly name: "PublicKeyInUse";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(opts: __ExceptionOptionType<PublicKeyInUse, __BaseException>);
}
export declare class RealtimeLogConfigInUse extends __BaseException {
  readonly name: "RealtimeLogConfigInUse";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<RealtimeLogConfigInUse, __BaseException>
  );
}
export declare class ResponseHeadersPolicyInUse extends __BaseException {
  readonly name: "ResponseHeadersPolicyInUse";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<ResponseHeadersPolicyInUse, __BaseException>
  );
}
export declare class NoSuchStreamingDistribution extends __BaseException {
  readonly name: "NoSuchStreamingDistribution";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<NoSuchStreamingDistribution, __BaseException>
  );
}
export declare class StreamingDistributionNotDisabled extends __BaseException {
  readonly name: "StreamingDistributionNotDisabled";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<
      StreamingDistributionNotDisabled,
      __BaseException
    >
  );
}
export declare class NoSuchInvalidation extends __BaseException {
  readonly name: "NoSuchInvalidation";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(opts: __ExceptionOptionType<NoSuchInvalidation, __BaseException>);
}
export declare class TestFunctionFailed extends __BaseException {
  readonly name: "TestFunctionFailed";
  readonly $fault: "server";
  Message?: string | undefined;
  constructor(opts: __ExceptionOptionType<TestFunctionFailed, __BaseException>);
}
