/**
 * ./src/krill/prepare.d/welcome.tsx
 * penguins-eggs v.25.7.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 * https://stackoverflow.com/questions/23876782/how-do-i-split-a-typescript-class-into-multiple-files
 */
import { INet } from '../../../interfaces/index.js';
import Prepare from '../prepare.js';
/**
 * Network
 */
export declare function network(this: Prepare): Promise<INet>;
