import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import {
  CloudFrontClientResolvedConfig,
  ServiceInputTypes,
  ServiceOutputTypes,
} from "../CloudFrontClient";
import {
  UpdateKeyValueStoreRequest,
  UpdateKeyValueStoreResult,
} from "../models/models_1";
export { __MetadataBearer };
export { $Command };
export interface UpdateKeyValueStoreCommandInput
  extends UpdateKeyValueStoreRequest {}
export interface UpdateKeyValueStoreCommandOutput
  extends UpdateKeyValueStoreResult,
    __MetadataBearer {}
declare const UpdateKeyValueStoreCommand_base: {
  new (
    input: UpdateKeyValueStoreCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    UpdateKeyValueStoreCommandInput,
    UpdateKeyValueStoreCommandOutput,
    CloudFrontClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  new (
    input: UpdateKeyValueStoreCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    UpdateKeyValueStoreCommandInput,
    UpdateKeyValueStoreCommandOutput,
    CloudFrontClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
export declare class UpdateKeyValueStoreCommand extends UpdateKeyValueStoreCommand_base {
  protected static __types: {
    api: {
      input: UpdateKeyValueStoreRequest;
      output: UpdateKeyValueStoreResult;
    };
    sdk: {
      input: UpdateKeyValueStoreCommandInput;
      output: UpdateKeyValueStoreCommandOutput;
    };
  };
}
