module.exports={A:{A:{"1":"A B","2":"K D E F 3C"},B:{"1":"C L M G N O P","516":"0 1 2 3 4 5 6 7 8 9 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I"},C:{"132":"0B 1B 2B 3B 4B 5B 6B XC 7B YC 8B 9B AC","164":"4C WC J cB K D E F A B C L M G N O P dB BB CB DB EB FB GB HB IB JB KB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 7C 8C","516":"BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a","1028":"0 1 2 3 4 5 6 7 8 9 b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC cC 5C 6C"},D:{"420":"J cB K D E F A B C L M G N O P dB BB CB DB EB FB GB HB IB JB KB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB","516":"0 1 2 3 4 5 6 7 8 9 yB zB 0B 1B 2B 3B 4B 5B 6B XC 7B YC 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC cC"},E:{"1":"A B C L M G eC QC RC ED FD GD fC gC SC HD TC hC iC jC kC lC ID UC mC nC oC pC qC JD VC rC sC tC uC vC wC xC yC zC 0C KD","132":"F DD","164":"D E CD","420":"J cB K 9C dC AD BD"},F:{"1":"C QC 1C PD RC","2":"F B LD MD ND OD","420":"G N O P dB BB CB DB EB FB GB HB IB JB KB eB fB gB hB iB jB kB","516":"0 1 2 3 4 5 6 7 8 9 lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB"},G:{"1":"XD YD ZD aD bD cD dD eD fD gD hD iD jD fC gC SC kD TC hC iC jC kC lC lD UC mC nC oC pC qC mD VC rC sC tC uC vC wC xC yC zC 0C","132":"VD WD","164":"E TD UD","420":"dC QD 2C RD SD"},H:{"1":"nD"},I:{"420":"WC J oD pD qD rD 2C sD tD","516":"I"},J:{"420":"D A"},K:{"1":"C QC 1C RC","2":"A B","516":"H"},L:{"516":"I"},M:{"1028":"PC"},N:{"1":"A B"},O:{"516":"SC"},P:{"420":"J","516":"BB CB DB EB FB GB HB IB JB KB uD vD wD xD yD eC zD 0D 1D 2D 3D TC UC VC 4D"},Q:{"516":"5D"},R:{"516":"6D"},S:{"164":"7D 8D"}},B:4,C:"CSS3 Multiple column layout",D:true};
