/**
 * ./src/commands/setup.ts
 * penguins-eggs v.25.11.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
import { Command } from '@oclif/core';
export default class Purge extends Command {
    static description: string;
    static examples: string[];
    /**
     *
     * @returns
     */
    run(): Promise<void>;
}
