/**
 * @public
 * @enum
 */
export declare const AccessDeniedExceptionReason: {
    readonly KMS_ACCESS_DENIED: "KMS_AccessDeniedException";
};
/**
 * @public
 */
export type AccessDeniedExceptionReason = (typeof AccessDeniedExceptionReason)[keyof typeof AccessDeniedExceptionReason];
/**
 * @public
 * @enum
 */
export declare const InvalidRequestExceptionReason: {
    readonly KMS_DISABLED_KEY: "KMS_DisabledException";
    readonly KMS_INVALID_KEY_USAGE: "KMS_InvalidKeyUsageException";
    readonly KMS_INVALID_STATE: "KMS_InvalidStateException";
    readonly KMS_KEY_NOT_FOUND: "KMS_NotFoundException";
};
/**
 * @public
 */
export type InvalidRequestExceptionReason = (typeof InvalidRequestExceptionReason)[keyof typeof InvalidRequestExceptionReason];
