/**
 * ./src/classes/incubation/distros/buster.ts
 * penguins-eggs v.25.7.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
import { IDistro, IInstaller, IRemix } from '../../../interfaces/index.js';
/**
 *
 */
export declare class Trixie {
    distro: IDistro;
    installer: IInstaller;
    isClone: boolean;
    release: boolean;
    remix: IRemix;
    theme: string;
    user_opt: string;
    verbose: boolean;
    /**
     * @param remix
     * @param distro
     * @param displaymanager
     * @param verbose
     */
    constructor(installer: IInstaller, remix: IRemix, distro: IDistro, user_opt: string, release?: boolean, theme?: string, isClone?: boolean, verbose?: boolean);
    /**
     * locale, partitions, users can come from themes
     */
    create(): Promise<void>;
}
