module.exports={A:{A:{"2":"K D E F 3C","132":"A B"},B:{"1":"0 1 2 3 4 5 6 7 8 9 C L M G N O P Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I"},C:{"1":"0 1 2 3 4 5 6 7 8 9 N O P dB BB CB DB EB FB GB HB IB JB KB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B XC 7B YC 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC cC 5C 6C","2":"4C WC J cB K D E F 7C 8C","33":"A B C L M G"},D:{"1":"0 1 2 3 4 5 6 7 8 9 kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B XC 7B YC 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC cC","2":"J cB K D E F A B","33":"C L M G N O P dB BB CB DB EB FB GB HB IB JB KB eB fB gB hB iB jB"},E:{"1":"gC SC HD TC hC iC jC kC lC ID UC mC nC oC pC qC JD VC rC sC tC uC vC wC xC yC zC 0C KD","2":"9C dC","33":"J cB K D E AD BD CD","257":"F A B C L M G DD eC QC RC ED FD GD fC"},F:{"1":"0 1 2 3 4 5 6 7 8 9 EB FB GB HB IB JB KB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB","2":"F B C LD MD ND OD QC 1C PD RC","33":"G N O P dB BB CB DB"},G:{"1":"gC SC kD TC hC iC jC kC lC lD UC mC nC oC pC qC mD VC rC sC tC uC vC wC xC yC zC 0C","33":"E dC QD 2C RD SD TD UD","257":"VD WD XD YD ZD aD bD cD dD eD fD gD hD iD jD fC"},H:{"2":"nD"},I:{"1":"I","2":"oD pD qD","33":"WC J rD 2C sD tD"},J:{"33":"D A"},K:{"1":"H","2":"A B C QC 1C RC"},L:{"1":"I"},M:{"1":"PC"},N:{"132":"A B"},O:{"1":"SC"},P:{"1":"J BB CB DB EB FB GB HB IB JB KB uD vD wD xD yD eC zD 0D 1D 2D 3D TC UC VC 4D"},Q:{"1":"5D"},R:{"1":"6D"},S:{"1":"7D 8D"}},B:5,C:"CSS3 3D Transforms",D:true};
