/**
 * penguins-eggs
 * class: distro.ts
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
import { IDistro } from '../interfaces/index.js';
/**
 * Classe
 */
declare class Distro implements IDistro {
    bugReportUrl: string;
    codenameId: string;
    distroId: string;
    distroLike: string;
    distroUniqueId: string;
    familyId: string;
    homeUrl: string;
    isCalamaresAvailable: boolean;
    liveMediumPath: string;
    releaseId: string;
    squashfs: string;
    supportUrl: string;
    syslinuxPath: string;
    usrLibPath: string;
    /**
     * Costruttore
     */
    constructor();
}
export default Distro;
