/**
 * @public
 * @enum
 */
export declare const ResponseHeadersPolicyAccessControlAllowMethodsValues: {
    readonly ALL: "ALL";
    readonly DELETE: "DELETE";
    readonly GET: "GET";
    readonly HEAD: "HEAD";
    readonly OPTIONS: "OPTIONS";
    readonly PATCH: "PATCH";
    readonly POST: "POST";
    readonly PUT: "PUT";
};
/**
 * @public
 */
export type ResponseHeadersPolicyAccessControlAllowMethodsValues = (typeof ResponseHeadersPolicyAccessControlAllowMethodsValues)[keyof typeof ResponseHeadersPolicyAccessControlAllowMethodsValues];
/**
 * @public
 * @enum
 */
export declare const ICPRecordalStatus: {
    readonly APPROVED: "APPROVED";
    readonly PENDING: "PENDING";
    readonly SUSPENDED: "SUSPENDED";
};
/**
 * @public
 */
export type ICPRecordalStatus = (typeof ICPRecordalStatus)[keyof typeof ICPRecordalStatus];
/**
 * @public
 * @enum
 */
export declare const Method: {
    readonly DELETE: "DELETE";
    readonly GET: "GET";
    readonly HEAD: "HEAD";
    readonly OPTIONS: "OPTIONS";
    readonly PATCH: "PATCH";
    readonly POST: "POST";
    readonly PUT: "PUT";
};
/**
 * @public
 */
export type Method = (typeof Method)[keyof typeof Method];
/**
 * @public
 * @enum
 */
export declare const IpAddressType: {
    readonly DualStack: "dualstack";
    readonly Ipv4: "ipv4";
    readonly Ipv6: "ipv6";
};
/**
 * @public
 */
export type IpAddressType = (typeof IpAddressType)[keyof typeof IpAddressType];
/**
 * @public
 * @enum
 */
export declare const IpamCidrStatus: {
    readonly Advertised: "advertised";
    readonly Advertising: "advertising";
    readonly Deprovisioned: "deprovisioned";
    readonly Deprovisioning: "deprovisioning";
    readonly FailedAdvertise: "failed-advertise";
    readonly FailedDeprovision: "failed-deprovision";
    readonly FailedProvision: "failed-provision";
    readonly FailedWithdraw: "failed-withdraw";
    readonly Provisioned: "provisioned";
    readonly Provisioning: "provisioning";
    readonly Withdrawing: "withdrawing";
    readonly Withdrawn: "withdrawn";
};
/**
 * @public
 */
export type IpamCidrStatus = (typeof IpamCidrStatus)[keyof typeof IpamCidrStatus];
/**
 * @public
 * @enum
 */
export declare const ItemSelection: {
    readonly all: "all";
    readonly none: "none";
    readonly whitelist: "whitelist";
};
/**
 * @public
 */
export type ItemSelection = (typeof ItemSelection)[keyof typeof ItemSelection];
/**
 * @public
 * @enum
 */
export declare const EventType: {
    readonly origin_request: "origin-request";
    readonly origin_response: "origin-response";
    readonly viewer_request: "viewer-request";
    readonly viewer_response: "viewer-response";
};
/**
 * @public
 */
export type EventType = (typeof EventType)[keyof typeof EventType];
/**
 * @public
 * @enum
 */
export declare const ViewerProtocolPolicy: {
    readonly allow_all: "allow-all";
    readonly https_only: "https-only";
    readonly redirect_to_https: "redirect-to-https";
};
/**
 * @public
 */
export type ViewerProtocolPolicy = (typeof ViewerProtocolPolicy)[keyof typeof ViewerProtocolPolicy];
/**
 * @public
 * @enum
 */
export declare const CachePolicyCookieBehavior: {
    readonly all: "all";
    readonly allExcept: "allExcept";
    readonly none: "none";
    readonly whitelist: "whitelist";
};
/**
 * @public
 */
export type CachePolicyCookieBehavior = (typeof CachePolicyCookieBehavior)[keyof typeof CachePolicyCookieBehavior];
/**
 * @public
 * @enum
 */
export declare const CachePolicyHeaderBehavior: {
    readonly none: "none";
    readonly whitelist: "whitelist";
};
/**
 * @public
 */
export type CachePolicyHeaderBehavior = (typeof CachePolicyHeaderBehavior)[keyof typeof CachePolicyHeaderBehavior];
/**
 * @public
 * @enum
 */
export declare const CachePolicyQueryStringBehavior: {
    readonly all: "all";
    readonly allExcept: "allExcept";
    readonly none: "none";
    readonly whitelist: "whitelist";
};
/**
 * @public
 */
export type CachePolicyQueryStringBehavior = (typeof CachePolicyQueryStringBehavior)[keyof typeof CachePolicyQueryStringBehavior];
/**
 * @public
 * @enum
 */
export declare const CachePolicyType: {
    readonly custom: "custom";
    readonly managed: "managed";
};
/**
 * @public
 */
export type CachePolicyType = (typeof CachePolicyType)[keyof typeof CachePolicyType];
/**
 * @public
 * @enum
 */
export declare const CertificateSource: {
    readonly acm: "acm";
    readonly cloudfront: "cloudfront";
    readonly iam: "iam";
};
/**
 * @public
 */
export type CertificateSource = (typeof CertificateSource)[keyof typeof CertificateSource];
/**
 * @public
 * @enum
 */
export declare const CertificateTransparencyLoggingPreference: {
    readonly Disabled: "disabled";
    readonly Enabled: "enabled";
};
/**
 * @public
 */
export type CertificateTransparencyLoggingPreference = (typeof CertificateTransparencyLoggingPreference)[keyof typeof CertificateTransparencyLoggingPreference];
/**
 * @public
 * @enum
 */
export declare const ConnectionMode: {
    readonly Direct: "direct";
    readonly TenantOnly: "tenant-only";
};
/**
 * @public
 */
export type ConnectionMode = (typeof ConnectionMode)[keyof typeof ConnectionMode];
/**
 * @public
 * @enum
 */
export declare const HttpVersion: {
    readonly http1_1: "http1.1";
    readonly http2: "http2";
    readonly http2and3: "http2and3";
    readonly http3: "http3";
};
/**
 * @public
 */
export type HttpVersion = (typeof HttpVersion)[keyof typeof HttpVersion];
/**
 * @public
 * @enum
 */
export declare const OriginGroupSelectionCriteria: {
    readonly Default: "default";
    readonly MediaQualityBased: "media-quality-based";
};
/**
 * @public
 */
export type OriginGroupSelectionCriteria = (typeof OriginGroupSelectionCriteria)[keyof typeof OriginGroupSelectionCriteria];
/**
 * @public
 * @enum
 */
export declare const OriginProtocolPolicy: {
    readonly http_only: "http-only";
    readonly https_only: "https-only";
    readonly match_viewer: "match-viewer";
};
/**
 * @public
 */
export type OriginProtocolPolicy = (typeof OriginProtocolPolicy)[keyof typeof OriginProtocolPolicy];
/**
 * @public
 * @enum
 */
export declare const SslProtocol: {
    readonly SSLv3: "SSLv3";
    readonly TLSv1: "TLSv1";
    readonly TLSv1_1: "TLSv1.1";
    readonly TLSv1_2: "TLSv1.2";
};
/**
 * @public
 */
export type SslProtocol = (typeof SslProtocol)[keyof typeof SslProtocol];
/**
 * @public
 * @enum
 */
export declare const PriceClass: {
    readonly None: "None";
    readonly PriceClass_100: "PriceClass_100";
    readonly PriceClass_200: "PriceClass_200";
    readonly PriceClass_All: "PriceClass_All";
};
/**
 * @public
 */
export type PriceClass = (typeof PriceClass)[keyof typeof PriceClass];
/**
 * @public
 * @enum
 */
export declare const GeoRestrictionType: {
    readonly blacklist: "blacklist";
    readonly none: "none";
    readonly whitelist: "whitelist";
};
/**
 * @public
 */
export type GeoRestrictionType = (typeof GeoRestrictionType)[keyof typeof GeoRestrictionType];
/**
 * @public
 * @enum
 */
export declare const MinimumProtocolVersion: {
    readonly SSLv3: "SSLv3";
    readonly TLSv1: "TLSv1";
    readonly TLSv1_1_2016: "TLSv1.1_2016";
    readonly TLSv1_2016: "TLSv1_2016";
    readonly TLSv1_2_2018: "TLSv1.2_2018";
    readonly TLSv1_2_2019: "TLSv1.2_2019";
    readonly TLSv1_2_2021: "TLSv1.2_2021";
    readonly TLSv1_2_2025: "TLSv1.2_2025";
    readonly TLSv1_3_2025: "TLSv1.3_2025";
};
/**
 * @public
 */
export type MinimumProtocolVersion = (typeof MinimumProtocolVersion)[keyof typeof MinimumProtocolVersion];
/**
 * @public
 * @enum
 */
export declare const SSLSupportMethod: {
    readonly sni_only: "sni-only";
    readonly static_ip: "static-ip";
    readonly vip: "vip";
};
/**
 * @public
 */
export type SSLSupportMethod = (typeof SSLSupportMethod)[keyof typeof SSLSupportMethod];
/**
 * @public
 * @enum
 */
export declare const ViewerMtlsMode: {
    readonly Optional: "optional";
    readonly Required: "required";
};
/**
 * @public
 */
export type ViewerMtlsMode = (typeof ViewerMtlsMode)[keyof typeof ViewerMtlsMode];
/**
 * @public
 * @enum
 */
export declare const FunctionRuntime: {
    readonly cloudfront_js_1_0: "cloudfront-js-1.0";
    readonly cloudfront_js_2_0: "cloudfront-js-2.0";
};
/**
 * @public
 */
export type FunctionRuntime = (typeof FunctionRuntime)[keyof typeof FunctionRuntime];
/**
 * @public
 * @enum
 */
export declare const FunctionStage: {
    readonly DEVELOPMENT: "DEVELOPMENT";
    readonly LIVE: "LIVE";
};
/**
 * @public
 */
export type FunctionStage = (typeof FunctionStage)[keyof typeof FunctionStage];
/**
 * @public
 * @enum
 */
export declare const ContinuousDeploymentPolicyType: {
    readonly SingleHeader: "SingleHeader";
    readonly SingleWeight: "SingleWeight";
};
/**
 * @public
 */
export type ContinuousDeploymentPolicyType = (typeof ContinuousDeploymentPolicyType)[keyof typeof ContinuousDeploymentPolicyType];
/**
 * @public
 * @enum
 */
export declare const CustomizationActionType: {
    readonly disable: "disable";
    readonly override: "override";
};
/**
 * @public
 */
export type CustomizationActionType = (typeof CustomizationActionType)[keyof typeof CustomizationActionType];
/**
 * @public
 * @enum
 */
export declare const ValidationTokenHost: {
    readonly CloudFront: "cloudfront";
    readonly SelfHosted: "self-hosted";
};
/**
 * @public
 */
export type ValidationTokenHost = (typeof ValidationTokenHost)[keyof typeof ValidationTokenHost];
/**
 * @public
 * @enum
 */
export declare const DomainStatus: {
    readonly Active: "active";
    readonly Inactive: "inactive";
};
/**
 * @public
 */
export type DomainStatus = (typeof DomainStatus)[keyof typeof DomainStatus];
/**
 * @public
 * @enum
 */
export declare const Format: {
    readonly URLEncoded: "URLEncoded";
};
/**
 * @public
 */
export type Format = (typeof Format)[keyof typeof Format];
/**
 * @public
 * @enum
 */
export declare const ImportSourceType: {
    readonly S3: "S3";
};
/**
 * @public
 */
export type ImportSourceType = (typeof ImportSourceType)[keyof typeof ImportSourceType];
/**
 * @public
 * @enum
 */
export declare const RealtimeMetricsSubscriptionStatus: {
    readonly Disabled: "Disabled";
    readonly Enabled: "Enabled";
};
/**
 * @public
 */
export type RealtimeMetricsSubscriptionStatus = (typeof RealtimeMetricsSubscriptionStatus)[keyof typeof RealtimeMetricsSubscriptionStatus];
/**
 * @public
 * @enum
 */
export declare const OriginAccessControlOriginTypes: {
    readonly lambda: "lambda";
    readonly mediapackagev2: "mediapackagev2";
    readonly mediastore: "mediastore";
    readonly s3: "s3";
};
/**
 * @public
 */
export type OriginAccessControlOriginTypes = (typeof OriginAccessControlOriginTypes)[keyof typeof OriginAccessControlOriginTypes];
/**
 * @public
 * @enum
 */
export declare const OriginAccessControlSigningBehaviors: {
    readonly always: "always";
    readonly never: "never";
    readonly no_override: "no-override";
};
/**
 * @public
 */
export type OriginAccessControlSigningBehaviors = (typeof OriginAccessControlSigningBehaviors)[keyof typeof OriginAccessControlSigningBehaviors];
/**
 * @public
 * @enum
 */
export declare const OriginAccessControlSigningProtocols: {
    readonly sigv4: "sigv4";
};
/**
 * @public
 */
export type OriginAccessControlSigningProtocols = (typeof OriginAccessControlSigningProtocols)[keyof typeof OriginAccessControlSigningProtocols];
/**
 * @public
 * @enum
 */
export declare const OriginRequestPolicyCookieBehavior: {
    readonly all: "all";
    readonly allExcept: "allExcept";
    readonly none: "none";
    readonly whitelist: "whitelist";
};
/**
 * @public
 */
export type OriginRequestPolicyCookieBehavior = (typeof OriginRequestPolicyCookieBehavior)[keyof typeof OriginRequestPolicyCookieBehavior];
/**
 * @public
 * @enum
 */
export declare const OriginRequestPolicyHeaderBehavior: {
    readonly allExcept: "allExcept";
    readonly allViewer: "allViewer";
    readonly allViewerAndWhitelistCloudFront: "allViewerAndWhitelistCloudFront";
    readonly none: "none";
    readonly whitelist: "whitelist";
};
/**
 * @public
 */
export type OriginRequestPolicyHeaderBehavior = (typeof OriginRequestPolicyHeaderBehavior)[keyof typeof OriginRequestPolicyHeaderBehavior];
/**
 * @public
 * @enum
 */
export declare const OriginRequestPolicyQueryStringBehavior: {
    readonly all: "all";
    readonly allExcept: "allExcept";
    readonly none: "none";
    readonly whitelist: "whitelist";
};
/**
 * @public
 */
export type OriginRequestPolicyQueryStringBehavior = (typeof OriginRequestPolicyQueryStringBehavior)[keyof typeof OriginRequestPolicyQueryStringBehavior];
/**
 * @public
 * @enum
 */
export declare const FrameOptionsList: {
    readonly DENY: "DENY";
    readonly SAMEORIGIN: "SAMEORIGIN";
};
/**
 * @public
 */
export type FrameOptionsList = (typeof FrameOptionsList)[keyof typeof FrameOptionsList];
/**
 * @public
 * @enum
 */
export declare const ReferrerPolicyList: {
    readonly no_referrer: "no-referrer";
    readonly no_referrer_when_downgrade: "no-referrer-when-downgrade";
    readonly origin: "origin";
    readonly origin_when_cross_origin: "origin-when-cross-origin";
    readonly same_origin: "same-origin";
    readonly strict_origin: "strict-origin";
    readonly strict_origin_when_cross_origin: "strict-origin-when-cross-origin";
    readonly unsafe_url: "unsafe-url";
};
/**
 * @public
 */
export type ReferrerPolicyList = (typeof ReferrerPolicyList)[keyof typeof ReferrerPolicyList];
/**
 * @public
 * @enum
 */
export declare const TrustStoreStatus: {
    readonly Active: "active";
    readonly Failed: "failed";
    readonly Pending: "pending";
};
/**
 * @public
 */
export type TrustStoreStatus = (typeof TrustStoreStatus)[keyof typeof TrustStoreStatus];
/**
 * @public
 * @enum
 */
export declare const ManagedCertificateStatus: {
    readonly Expired: "expired";
    readonly Failed: "failed";
    readonly Inactive: "inactive";
    readonly Issued: "issued";
    readonly PendingValidation: "pending-validation";
    readonly Revoked: "revoked";
    readonly ValidationTimedOut: "validation-timed-out";
};
/**
 * @public
 */
export type ManagedCertificateStatus = (typeof ManagedCertificateStatus)[keyof typeof ManagedCertificateStatus];
/**
 * @public
 * @enum
 */
export declare const DistributionResourceType: {
    readonly Distribution: "distribution";
    readonly DistributionTenant: "distribution-tenant";
};
/**
 * @public
 */
export type DistributionResourceType = (typeof DistributionResourceType)[keyof typeof DistributionResourceType];
/**
 * @public
 * @enum
 */
export declare const OriginRequestPolicyType: {
    readonly custom: "custom";
    readonly managed: "managed";
};
/**
 * @public
 */
export type OriginRequestPolicyType = (typeof OriginRequestPolicyType)[keyof typeof OriginRequestPolicyType];
/**
 * @public
 * @enum
 */
export declare const ResponseHeadersPolicyType: {
    readonly custom: "custom";
    readonly managed: "managed";
};
/**
 * @public
 */
export type ResponseHeadersPolicyType = (typeof ResponseHeadersPolicyType)[keyof typeof ResponseHeadersPolicyType];
/**
 * @public
 * @enum
 */
export declare const DnsConfigurationStatus: {
    readonly Invalid: "invalid-configuration";
    readonly Unknown: "unknown-configuration";
    readonly Valid: "valid-configuration";
};
/**
 * @public
 */
export type DnsConfigurationStatus = (typeof DnsConfigurationStatus)[keyof typeof DnsConfigurationStatus];
