export * from "./jsx-automatic.js";
export const Fragment: null;
export const jsx: {
    (type: null, props: {
        children?: import("./create-h.js").Child;
    }, key?: string | undefined): import("hast").Root;
    (type: string, props: import("./create-automatic-runtime.js").JSXProps, key?: string | undefined): import("hast").Element;
};
export const jsxDEV: {
    (type: null, props: {
        children?: import("./create-h.js").Child;
    }, key?: string | undefined): import("hast").Root;
    (type: string, props: import("./create-automatic-runtime.js").JSXProps, key?: string | undefined): import("hast").Element;
};
export const jsxs: {
    (type: null, props: {
        children?: import("./create-h.js").Child;
    }, key?: string | undefined): import("hast").Root;
    (type: string, props: import("./create-automatic-runtime.js").JSXProps, key?: string | undefined): import("hast").Element;
};
