/**
 * ./src/components/location.tsx
 * penguins-eggs v.25.7.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
import React from 'react';
type LocationProps = {
    dateNumbers?: string;
    language?: string;
    region?: string;
    zone?: string;
};
export default function Location({ dateNumbers, language, region, zone }: LocationProps): React.JSX.Element;
export {};
