/**
 * ./src/krill/classes/secquence.d/add-user.ts
 * penguins-eggs v.25.7.x / ecmascript 2020
 * REFACTORED: Uses "The SysUser Master" class.
 * Replaces chroot/binary dependencies with pure Node.js manipulation.
 */
import Sequence from '../sequence.js';
export default function addUser(this: Sequence, username?: string, password?: string, fullusername?: string, roomNumber?: string, workPhone?: string, homePhone?: string): Promise<void>;
