import { GetRoleCredentialsCommand, SSOClient } from "@aws-sdk/nested-clients/sso";
export { GetRoleCredentialsCommand, SSOClient };
export type { SSOClientConfig, GetRoleCredentialsCommandOutput } from "@aws-sdk/nested-clients/sso";
