"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var changeCase = require(".");
describe("change case", function () {
    it("exports expected methods", function () {
        expect(typeof changeCase).toEqual("object");
    });
});
//# sourceMappingURL=index.spec.js.map