/**
 * Cerca il file .preset per mkinitcpio appropriato per il kernel corrente.
 * @returns Il percorso del file .preset trovato.
 * @throws {Error} Se non è possibile trovare un file .preset valido.
 */
export declare function initcpio(): Promise<string>;
