import { Paginator } from "@smithy/types";
import {
  ListPartsCommandInput,
  ListPartsCommandOutput,
} from "../commands/ListPartsCommand";
import { S3PaginationConfiguration } from "./Interfaces";
export declare const paginateListParts: (
  config: S3PaginationConfiguration,
  input: ListPartsCommandInput,
  ...rest: any[]
) => Paginator<ListPartsCommandOutput>;
