import { SourceData, Checksum } from "@aws-sdk/types";
export declare class AwsCrc32 implements Checksum {
    private crc32;
    update(toHash: SourceData): void;
    digest(): Promise<Uint8Array>;
    reset(): void;
}
