/**
 * util.ts
 *
 * used in dhcpd
 *
 */
/**
 *
 * @param _buffer
 * @param byteArray
 * @param offset
 * @returns
 */
export declare const writeBytes: (_buffer: any, byteArray: any, offset: number) => undefined;
/**
 *
 * @param _buffer
 * @param integer
 * @param offset
 * @returns
 */
export declare function writeInt32(_buffer: any, integer: number, offset: number): number;
/**
 *
 * @param _buffer
 * @param integer
 * @param offset
 * @returns
 */
export declare function writeInt16(_buffer: any, integer: number, offset: number): number;
/**
 *
 * @param _buffer
 * @param integer
 * @param offset
 * @returns
 */
export declare function writeInt8(_buffer: any, integer: number, offset: number): number;
/**
 *
 * @param _buffer
 * @param length
 * @param copy
 * @param offset
 * @returns
 */
export declare function readBytes(_buffer: any, length: number, copy: any, offset: number): any;
/**
 *
 * @param _buffer
 * @param offset
 * @returns
 */
export declare function readInt32(_buffer: any, offset: number): number;
/**
 *
 * @param _buffer
 * @param offset
 * @returns
 */
export declare function readInt16(_buffer: any, offset: number): number;
/**
 *
 * @param _buffer
 * @param offset
 * @returns
 */
export declare function readInt8(_buffer: any, offset: number): any;
/**
 *
 * @param buf
 * @returns
 */
export declare function readString(buf: any): string;
/**
 *
 * @param buf
 * @returns
 */
export declare function readHex(buf: any): string;
/**
 *
 * @param buf
 * @returns
 */
export declare function readHexAddress(buf: any): string;
/**
 *
 * @param buffer
 * @param offset
 * @returns
 */
export declare function readIp(buffer: any, offset: number): string | undefined;
/**
 *
 * @param buffer
 * @returns
 */
export declare function readMacAddress(buffer: any): string;
/**
 *
 * @param buf
 * @param num
 * @param offsetHours
 * @param offset
 * @returns
 */
export declare function writeTimeOffset(buf: any, num: any, offsetHours: any, offset: number): number;
/**
 *
 * @param buf
 * @param num
 * @param ip
 * @param offset
 * @returns
 */
export declare function writeIp(buf: any, num: string, ip: any, offset: number): number;
/**
 *
 * @param buf
 * @param num
 * @param hostname
 * @param offset
 * @returns
 */
export declare function writeString(buf: any, num: string, hostname: string, offset: number): number;
