import type { CodecSettings } from "@smithy/types";
/**
 * @internal
 */
export type QuerySerializerSettings = CodecSettings & {
    capitalizeKeys?: boolean;
    flattenLists?: boolean;
    serializeEmptyLists?: boolean;
    /**
     * Whether to read from ec2QueryName before xmlName.
     */
    ec2?: boolean;
};
