/**
 * src/classes/ovary.d/user-create-live.ts
 * penguins-eggs v.25.7.x / ecmascript 2020
 * REFACTORED: Uses "The SysUser Master" class.
 * Creates the live user directly in the merged filesystem safely.
 */
import Ovary from '../ovary.js';
export default function userCreateLive(this: Ovary): Promise<void>;
