/**
 * ./src/classes/ovary.d/bind-live-fs.ts
 * penguins-eggs v.25.7.x / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
import Ovary from '../ovary.js';
/**
 * bind dei virtual file system
 */
export declare function bindVfs(this: Ovary): Promise<void>;
/**
 *
 * @param verbose
 */
export declare function ubindVfs(this: Ovary): Promise<void>;
