/** @type {ReturnType<createH>} */
export const h: ReturnType<typeof createH>;
export namespace h {
    namespace JSX {
        type Element = import('./jsx-classic.js').Element;
        type ElementChildrenAttribute = import('./jsx-classic.js').ElementChildrenAttribute;
        type IntrinsicAttributes = import('./jsx-classic.js').IntrinsicAttributes;
        type IntrinsicElements = import('./jsx-classic.js').IntrinsicElements;
    }
}
/** @type {ReturnType<createH>} */
export const s: ReturnType<typeof createH>;
export namespace s {
    namespace JSX {
        type Element = import('./jsx-classic.js').Element;
        type ElementChildrenAttribute = import('./jsx-classic.js').ElementChildrenAttribute;
        type IntrinsicAttributes = import('./jsx-classic.js').IntrinsicAttributes;
        type IntrinsicElements = import('./jsx-classic.js').IntrinsicElements;
    }
}
/**
 * Acceptable child value.
 */
export type Child = import('./create-h.js').Child;
/**
 * Acceptable value for element properties.
 */
export type Properties = import('./create-h.js').Properties;
/**
 * Result from a `h` (or `s`) call.
 */
export type Result = import('./create-h.js').Result;
import { createH } from './create-h.js';
