/**
 * penguins-eggs
 * Kernel management utilities
 */
export default class Kernel {
    /**
     * Cerca initramfs
     */
    static initramfs(kernel?: string): string;
    /**
     * Ricava path per vmlinuz (o vmlinux su RISC-V)
     */
    static vmlinuz(kernel?: string): string;
    /**
     * PRIVATE METHODS
     */
    private static vmlinuzFromCmdline;
    private static vmlinuzFromUname;
}
