module.exports={A:{A:{"2436":"K D E F A B 3C"},B:{"260":"O P","2436":"C L M G N","8196":"0 1 2 3 4 5 6 7 8 9 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I"},C:{"2":"4C WC J cB K D E F A B C L M G N O P dB BB CB 7C 8C","772":"DB EB FB GB HB IB JB KB eB fB gB hB iB jB kB lB mB nB oB","4100":"0 1 2 3 4 5 6 7 8 9 pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B XC 7B YC 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC cC 5C 6C"},D:{"2":"J cB K D E F A B C","2564":"L M G N O P dB BB CB DB EB FB GB HB IB JB KB eB fB gB hB iB jB kB lB mB nB oB pB qB","8196":"0 1 2 3 4 5 6 7 8 9 6B XC 7B YC 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB I aC PC bC cC","10244":"rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B"},E:{"1":"C L M G RC ED FD GD fC gC SC HD TC hC iC jC kC lC ID UC mC nC oC pC qC JD VC rC sC tC uC vC wC xC yC zC 0C KD","16":"9C dC","2308":"A B eC QC","2820":"J cB K D E F AD BD CD DD"},F:{"2":"F B LD MD ND OD QC 1C PD","16":"C","516":"RC","2564":"G N O P dB BB CB DB EB FB GB HB IB JB KB","8196":"0 1 2 3 4 5 6 7 8 9 tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC Q H R ZC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB","10244":"eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB"},G:{"1":"bD cD dD eD fD gD hD iD jD fC gC SC kD TC hC iC jC kC lC lD UC mC nC oC pC qC mD VC rC sC tC uC vC wC xC yC zC 0C","2":"dC QD 2C","2820":"E RD SD TD UD VD WD XD YD ZD aD"},H:{"2":"nD"},I:{"2":"WC J oD pD qD rD 2C","260":"I","2308":"sD tD"},J:{"2":"D","2308":"A"},K:{"2":"A B C QC 1C","16":"RC","8196":"H"},L:{"8196":"I"},M:{"1028":"PC"},N:{"2":"A B"},O:{"8196":"SC"},P:{"2052":"uD vD","2308":"J","8196":"BB CB DB EB FB GB HB IB JB KB wD xD yD eC zD 0D 1D 2D 3D TC UC VC 4D"},Q:{"8196":"5D"},R:{"8196":"6D"},S:{"4100":"7D 8D"}},B:5,C:"Synchronous Clipboard API",D:true};
