import { TypeRegistry } from "@smithy/core/schema";
import type { StaticErrorSchema, StaticOperationSchema, StaticStructureSchema } from "@smithy/types";
export declare var SigninServiceException$: StaticErrorSchema;
export declare var AccessDeniedException$: StaticErrorSchema;
export declare var InternalServerException$: StaticErrorSchema;
export declare var TooManyRequestsError$: StaticErrorSchema;
export declare var ValidationException$: StaticErrorSchema;
/**
 * TypeRegistry instances containing modeled errors.
 * @internal
 *
 */
export declare const errorTypeRegistries: TypeRegistry[];
export declare var AccessToken$: StaticStructureSchema;
export declare var CreateOAuth2TokenRequest$: StaticStructureSchema;
export declare var CreateOAuth2TokenRequestBody$: StaticStructureSchema;
export declare var CreateOAuth2TokenResponse$: StaticStructureSchema;
export declare var CreateOAuth2TokenResponseBody$: StaticStructureSchema;
export declare var CreateOAuth2Token$: StaticOperationSchema;
